/*
 *  JDesigner (R) Web Application Development Platform 
 *  Copyright (C) 2010 JDesigner / SangBoo Lee (leesangboo@gmail.com)
 * 
 *  http://www.jdesigner.org/
 *  
 *  Please contact if you require licensing terms other
 *  than GPL-3 for this software.
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.jdesigner.application.template.dao;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

import org.jdesigner.platform.db.query.NamedQuery;
import org.jdesigner.platform.db.query.TableQuery;
import org.jdesigner.platform.exception.DatabaseException;
import org.jdesigner.platform.util.DateUtils;

public class HomeDAO extends ProjectBaseDAO {

	//private static final Log log = LogFactory.getLog(HomeDAO.class);

	public List selectLeftWebTopLetList(Map params) throws DatabaseException {
		params.put("column_align", "LEFT");
		NamedQuery query = persistence.newNamedQuery(DAOConstants.BASE_PATH + "/HomeDAO.selectWebTopLetLayoutByUsername.xml", params);
		return query.execute().selectList(); //
	}

	public List selectRightWebTopLetList(Map params) throws DatabaseException {
		params.put("column_align", "RIGHT");
		NamedQuery query = persistence.newNamedQuery(DAOConstants.BASE_PATH + "/HomeDAO.selectWebTopLetLayoutByUsername.xml", params);
		return query.execute().selectList(); //
	}

	public List selectUndselectedWebTopLetList(Map params) throws DatabaseException {
		NamedQuery query = persistence.newNamedQuery(DAOConstants.BASE_PATH + "/HomeDAO.selectUndselectedWebTopLetListByUsername.xml", params);
		return query.execute().selectList(); //
	}

	public void saveWebTopLetLayout(String username, String column_align, List webtoplet_list, boolean is_delete) throws DatabaseException {
		try {
			persistence.startTransaction();

			//
			if (is_delete) {
				Map delete_params = new HashMap();
				delete_params.put("username", username);
				delete_params.put("column_align", column_align);
				TableQuery delete_query = persistence.newTableQuery("PLF_WEBTOPLET_LAYOUT", new String[] { "username", "column_align" }, delete_params);
				delete_query.execute().delete();
			}
			//
			boolean reverse = false;
			for (int i = 0; webtoplet_list != null && i < webtoplet_list.size(); i++) {
				Map params = (Map) webtoplet_list.get(i);
				//
				params.put("username", username);
				if (!is_delete) {
					params.put("column_align", reverse ? "RIGHT" : "LEFT");
				}
				params.put("insert_date", DateUtils.getToTimestamp());
				TableQuery query = persistence.newTableQuery("PLF_WEBTOPLET_LAYOUT", params);
				query.execute().insert();
				//
				reverse = !reverse;
			}
			persistence.commitTransaction();
		} catch (Exception ex) {
			throw new DatabaseException("Error save WebTopLetLayout.", ex);
		} finally {
			persistence.endTransaction();
		}
	}

	public void closeWebTopLet(String username, Map params) throws DatabaseException {
		params.put("username", username);
		TableQuery delete_query = persistence.newTableQuery("PLF_WEBTOPLET_LAYOUT", new String[] { "webtoplet_id", "username" }, params);
		delete_query.execute().delete();
	}

}
