/*
 *  JDesigner (R) Web Application Development Platform 
 *  Copyright (C) 2010 JDesigner / SangBoo Lee (leesangboo@gmail.com)
 * 
 *  http://www.jdesigner.org/
 *  
 *  Please contact if you require licensing terms other
 *  than GPL-3 for this software.
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.jdesigner.application.template.dao;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import org.jdesigner.platform.data.DataMap;
import org.jdesigner.platform.db.query.NamedQuery;
import org.jdesigner.platform.exception.DatabaseException;

/**
 * <B>Login DAO</B>
 * 
 * @author leesangboo
 * 
 */
public class LoginDAO extends ProjectBaseDAO {

	private static final Log log = LogFactory.getLog(LoginDAO.class);

	public LoginDAO() {

	}

	/**
	 * 사용자 로그인 테이블에서 사용자 이름과 암호가 일치하는지 확인한다.
	 * 
	 * @param username
	 * @param password
	 * @return
	 * @throws DatabaseException
	 */
	public boolean checkLogin(String username, String password) throws DatabaseException {

		Map params = new HashMap();
		params.put("username", username);
		params.put("password", password);
		NamedQuery query = persistence.newNamedQuery(DAOConstants.BASE_PATH + "/LoginDAO.checkLogin.xml", params);
		List list = query.execute().selectList(); //

		return (list != null && list.size() > 0) ? true : false;
	}

	/**
	 * 사용자의 롤을 반환한다.
	 * 
	 * @param username
	 * @return
	 * @throws DatabaseException
	 */
	public List getUserRoles(String username) throws DatabaseException {

		Map params = new HashMap();
		params.put("username", username);

		NamedQuery query = persistence.newNamedQuery(DAOConstants.BASE_PATH + "/LoginDAO.getUserRole.xml", params);
		List list = query.execute().selectList(); //
		log.debug("role list = [" + list + "]");

		List roleList = new ArrayList();
		for (int i = 0; list != null && i < list.size(); i++) {
			DataMap data = (DataMap) list.get(i);
			roleList.add(data.getString("role_id")); //
		}

		return roleList;
	}

}
