/*
 *  JDesigner (R) Web Application Development Platform 
 *  Copyright (C) 2010 JDesigner / SangBoo Lee (leesangboo@gmail.com)
 * 
 *  http://www.jdesigner.org/
 *  
 *  Please contact if you require licensing terms other
 *  than GPL-3 for this software.
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.jdesigner.application.template.dao;

import java.sql.Timestamp;
import java.util.ArrayList;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import org.jdesigner.platform.data.DataMap;
import org.jdesigner.platform.data.Tree;
import org.jdesigner.platform.db.query.NamedQuery;
import org.jdesigner.platform.db.query.TableQuery;
import org.jdesigner.platform.exception.DatabaseException;

public class MenuDAO extends ProjectBaseDAO {

	private static final Log log = LogFactory.getLog(MenuDAO.class);

	/**
	 * CodeDAO
	 */
	public MenuDAO() {
		log.debug("MenuDAO init...");

	}

	public List selectFullMenuTreeList() throws DatabaseException {
		List fullMenuList = new ArrayList();
		Map params = new HashMap();
		params.put("is_use", "Y");
		NamedQuery query = persistence.newNamedQuery(DAOConstants.BASE_PATH + "/MenuDAO.selectFullMenuTreeList.xml", params);
		List menuList = query.execute().selectList(); //
		for (int i = 0; i < menuList.size(); i++) {
			Map menu = (DataMap) menuList.get(i);
			List roleMapList = this.selectMenuTreeRoleList(menu);
			//
			List roleList = new ArrayList();
			for (int j = 0; roleMapList != null && j < roleMapList.size(); j++) {
				DataMap role = (DataMap) roleMapList.get(j);
				roleList.add(role.getString("menu_role"));
			}
			menu.put("role_list", roleList);
			fullMenuList.add(menu);
		}
		return fullMenuList;
	}

	public Tree selectMenuTreeByUsername(Map params) throws DatabaseException {
		NamedQuery query = persistence.newNamedQuery(DAOConstants.BASE_PATH + "/MenuDAO.selectMenuTreeByUsername.xml", params);
		return query.execute().selectTree("menu_code", "parent_menu_code"); //
	}

	public List selectMenuTreeList(Map params) throws DatabaseException {
		NamedQuery query = persistence.newNamedQuery(DAOConstants.BASE_PATH + "/MenuDAO.selectMenuTreeList.xml", params);
		return query.execute().selectList(); //
	}

	public List selectMenuLevelList(Map params) throws DatabaseException {
		NamedQuery query = persistence.newNamedQuery(DAOConstants.BASE_PATH + "/MenuDAO.selectMenuLevelList.xml", params);
		return query.execute().selectList(); //
	}

	public List selectPrimaryMenuList() throws DatabaseException {
		List primaryMenuList = new ArrayList();
		NamedQuery query = persistence.newNamedQuery(DAOConstants.BASE_PATH + "/MenuDAO.selectPrimaryMenuList.xml", null);
		List menuList = query.execute().selectList(); //
		for (int i = 0; i < menuList.size(); i++) {
			Map menu = (DataMap) menuList.get(i);
			List roleMapList = this.selectMenuTreeRoleList(menu);
			//
			List roleList = new ArrayList();
			for (int j = 0; roleMapList != null && j < roleMapList.size(); j++) {
				DataMap role = (DataMap) roleMapList.get(j);
				roleList.add(role.getString("menu_role"));
			}
			menu.put("role_list", roleList);
			primaryMenuList.add(menu);
		}
		return primaryMenuList;
	}

	public List selectSecondMenuList(String parent_menu_code) throws DatabaseException {
		Map params = new HashMap();
		params.put("parent_menu_code", parent_menu_code);
		params.put("menu_level", "2");
		NamedQuery query = persistence.newNamedQuery(DAOConstants.BASE_PATH + "/MenuDAO.selectMenuTreeList.xml", params);
		return query.execute().selectList(); //
	}

	public List selectThirdMenuList(String parent_menu_code) throws DatabaseException {
		Map params = new HashMap();
		params.put("parent_menu_code", parent_menu_code);
		params.put("menu_level", "3");
		NamedQuery query = persistence.newNamedQuery(DAOConstants.BASE_PATH + "/MenuDAO.selectMenuTreeList.xml", params);
		return query.execute().selectList(); //
	}

	public Map selectMenuByURL(String url) throws DatabaseException {
		Map params = new HashMap();
		params.put("url", url);
		NamedQuery query = persistence.newNamedQuery(DAOConstants.BASE_PATH + "/MenuDAO.selectMenuByURL.xml", params);
		return query.execute().selectMap(); //
	}

	public Map selectMenuByURLAndPattern(String url) throws DatabaseException {
		Map params = new HashMap();
		params.put("url", url);
		NamedQuery query = persistence.newNamedQuery(DAOConstants.BASE_PATH + "/MenuDAO.selectMenuByURLAndPattern.xml", params);
		return query.execute().selectMap(); //
	}

	public Map selectMenuByDir(String url) throws DatabaseException {
		Map params = new HashMap();
		params.put("url", url);
		NamedQuery query = persistence.newNamedQuery(DAOConstants.BASE_PATH + "/MenuDAO.selectMenuByDir.xml", params);
		return query.execute().selectMap(); //
	}

	public Map selectMenu(Map params) throws DatabaseException {
		TableQuery query = persistence.newTableQuery("PLF_MENU_TREE", params);
		return query.execute().selectByPrimaryKey();
	}

	public void insertMenu(Map params, List auth_role_list) throws DatabaseException {
		try {
			persistence.startTransaction();
			params.put("insert_date", new Timestamp(new Date().getTime()));
			TableQuery query = persistence.newTableQuery("PLF_MENU_TREE", params);
			query.execute().insert();
			for (int i = 0; auth_role_list != null && i < auth_role_list.size(); i++) {
				Map map = (Map) auth_role_list.get(i);
				map.put("menu_code", params.get("menu_code"));
				TableQuery rtq = persistence.newTableQuery("PLF_MENU_TREE_ROLE", map);
				rtq.execute().insert();
			}
			persistence.commitTransaction();
		} catch (Exception ex) {
			throw new DatabaseException(ex.getMessage());
		} finally {
			persistence.endTransaction();
		}

	}

	public void updateMenu(Map params, List auth_role_list) throws DatabaseException {
		try {

			params.put("last_update_date", new Timestamp(new Date().getTime()));

			persistence.startTransaction();
			TableQuery query = persistence.newTableQuery("PLF_MENU_TREE", params);
			query.execute().update();

			TableQuery detailQuery = persistence.newTableQuery("PLF_MENU_TREE_ROLE", new String[] { "menu_code" }, params);
			detailQuery.execute().delete();

			for (int i = 0; auth_role_list != null && i < auth_role_list.size(); i++) {
				Map map = (Map) auth_role_list.get(i);
				map.put("menu_code", params.get("menu_code"));
				TableQuery rtq = persistence.newTableQuery("PLF_MENU_TREE_ROLE", map);
				rtq.execute().insert();
			}

			persistence.commitTransaction();
		} catch (Exception ex) {
			throw new DatabaseException(ex.getMessage());
		} finally {
			persistence.endTransaction();
		}
	}

	public void deleteMenu(Map params) throws DatabaseException {
		try {

			persistence.startTransaction();

			TableQuery query = persistence.newTableQuery("PLF_MENU_TREE", params);
			query.execute().delete();

			TableQuery detailQuery = persistence.newTableQuery("PLF_MENU_TREE_ROLE", new String[] { "menu_code" }, params);
			detailQuery.execute().delete();

			persistence.commitTransaction();

		} catch (Exception ex) {

			throw new DatabaseException(ex.getMessage());
		} finally {
			persistence.endTransaction();
		}
	}

	public List selectMenuTreeRoleList(Map params) throws DatabaseException {
		NamedQuery query = persistence.newNamedQuery(DAOConstants.BASE_PATH + "/MenuDAO.selectMenuTreeRoleList.xml", params);
		return query.execute().selectList(); //
	}

	public Map selectMenuRole(Map params) throws DatabaseException {
		TableQuery query = persistence.newTableQuery("PLF_MENU_TREE_ROLE", params);
		return query.execute().selectByPrimaryKey();
	}

	public void insertMenuRole(Map params) throws DatabaseException {
		params.put("insert_date", new Timestamp(new Date().getTime()));
		TableQuery query = persistence.newTableQuery("PLF_MENU_TREE_ROLE", params);
		query.execute().insert();
	}

	public void updateMenuRole(Map params) throws DatabaseException {
		params.put("last_update_date", new Timestamp(new Date().getTime()));
		TableQuery query = persistence.newTableQuery("PLF_MENU_TREE_ROLE", params, true);
		query.execute().update();
	}

	public void deleteMenuRole(Map params) throws DatabaseException {
		TableQuery query = persistence.newTableQuery("PLF_MENU_TREE_ROLE", params);
		query.execute().delete();
	}

}
