/*
 *  JDesigner (R) Web Application Development Platform 
 *  Copyright (C) 2010 JDesigner / SangBoo Lee (leesangboo@gmail.com)
 * 
 *  http://www.jdesigner.org/
 *  
 *  Please contact if you require licensing terms other
 *  than GPL-3 for this software.
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.jdesigner.application.template.dao;

import java.util.List;
import java.util.Map;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import org.jdesigner.platform.data.Page;
import org.jdesigner.platform.db.domain.Sequence;
import org.jdesigner.platform.db.query.NamedQuery;
import org.jdesigner.platform.db.query.TableQuery;
import org.jdesigner.platform.exception.DatabaseException;
import org.jdesigner.platform.util.DateUtils;

public class NoticeDAO extends ProjectBaseDAO {

	private static final long serialVersionUID = 1L;

	private static final Log log = LogFactory.getLog(NoticeDAO.class);

	public NoticeDAO() {
		init(); //
	}

	private void init() {
		//
		log.info("DAO[" + this.getClass() + "] initialize...");
	}

	public Page selectNoticePage(Map params, int start, int range, String sort, boolean desc) throws DatabaseException {
		NamedQuery query = persistence.newNamedQuery(DAOConstants.BASE_PATH + "/NoticeDAO.selectNoticePage.xml", params);
		return query.execute().selectPage(start, range, sort, desc); //
	}

	public List selectNoticeList(Map params) throws DatabaseException {
		NamedQuery query = persistence.newNamedQuery(DAOConstants.BASE_PATH + "/NoticeDAO.selectNoticePage.xml", params);
		return query.execute().selectList(); //
	}

	public List selectNoticeListByToday(Map params) throws DatabaseException {
		NamedQuery query = persistence.newNamedQuery(DAOConstants.BASE_PATH + "/NoticeDAO.selectNoticeListByToday.xml", params);
		return query.execute().selectList(); //
	}

	public Map selectNoticeMap(Map params) throws DatabaseException {
		TableQuery query = getPersistence().newTableQuery("PLF_NOTICE", params);
		return query.execute().selectByPrimaryKey(); //
	}

	public void insertNotice(Map params) throws DatabaseException {
		TableQuery query = getPersistence().newTableQuery("PLF_NOTICE", params);
		query.addParameter("notice_seq", new Sequence("PLF_NOTICE_SEQ"));
		query.addParameter(INSERT_DATE_COLUMN, DateUtils.getToTimestamp());
		query.execute().insert();
	}

	public void updateNotice(Map params) throws DatabaseException {
		TableQuery query = getPersistence().newTableQuery("PLF_NOTICE", params, true);
		query.addParameter(LAST_UPDATE_DATE_COLUMN, DateUtils.getToTimestamp());
		query.execute().update();
	}

	public void deleteNotice(Map params) throws DatabaseException {
		TableQuery query = getPersistence().newTableQuery("PLF_NOTICE", params);
		query.execute().delete();
	}
}
