/*
 *  JDesigner (R) Web Application Development Platform 
 *  Copyright (C) 2010 JDesigner / SangBoo Lee (leesangboo@gmail.com)
 * 
 *  http://www.jdesigner.org/
 *  
 *  Please contact if you require licensing terms other
 *  than GPL-3 for this software.
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.jdesigner.application.template.dao;

import java.sql.Timestamp;
import java.util.Date;
import java.util.List;
import java.util.Map;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import org.jdesigner.platform.data.Page;
import org.jdesigner.platform.db.query.NamedQuery;
import org.jdesigner.platform.db.query.TableQuery;
import org.jdesigner.platform.exception.DatabaseException;

/**
 * 사용자 DAO
 * 
 * @author leesangboo
 * 
 */
public class UserDAO extends ProjectBaseDAO {

	private static final Log log = LogFactory.getLog(UserDAO.class);

	public UserDAO() {
		log.debug("UserDAO init...");
	}

	/**
	 * 사용자 로그인 계정 페이지를 조회한다.
	 * 
	 * @param params
	 * @param start
	 * @param range
	 * @return
	 * @throws Exception
	 */
	public Page selectUserLoginPage(Map params, int start, int range, String sort, boolean desc) throws DatabaseException {
		NamedQuery query = persistence.newNamedQuery(DAOConstants.BASE_PATH + "/UserDAO.selectUserLoginPage.xml", params);
		return query.execute().selectPage(start, range, sort, desc); //
	}

	/**
	 * 사용자 로그인 계정을 반환한다.
	 * 
	 * @param params
	 * @return
	 * @throws DatabaseException
	 */
	public Map selectUserLogin(Map params) throws DatabaseException {
		TableQuery query = persistence.newTableQuery("PLF_USER_LOGIN", params);
		return query.execute().selectByPrimaryKey();
	}

	/**
	 * 로그인 계정을 등록한다.
	 * 
	 * @param params
	 * @throws DatabaseException
	 */
	public void insertUserLogin(Map params, List auth_group_list, List auth_role_list) throws DatabaseException {
		try {
			params.put("insert_date", new Timestamp(new Date().getTime()));
			persistence.startTransaction();
			TableQuery query = persistence.newTableQuery("PLF_USER_LOGIN", params);
			query.execute().insert();
			for (int i = 0; auth_group_list != null && i < auth_group_list.size(); i++) {
				Map map = (Map) auth_group_list.get(i);
				map.put("username", params.get("username"));
				TableQuery rtq = persistence.newTableQuery("PLF_USER_GROUP", map);
				rtq.execute().insert();
			}

			for (int i = 0; auth_role_list != null && i < auth_role_list.size(); i++) {
				Map map = (Map) auth_role_list.get(i);
				map.put("username", params.get("username"));
				TableQuery rtq = persistence.newTableQuery("PLF_USER_ROLE", map);
				rtq.execute().insert();
			}
			persistence.commitTransaction();
		} catch (Exception ex) {
			throw new DatabaseException("User login insert error :" + ex.getMessage());
		} finally {
			persistence.endTransaction();
		}
	}

	/**
	 * 로그인 계정을 수정한다.
	 * 
	 * @param params
	 * @throws DatabaseException
	 */
	public void updateUserLogin(Map params, List auth_group_list, List auth_role_list) throws DatabaseException {
		try {

			//
			persistence.startTransaction();

			//
			params.put("last_update_date", new Timestamp(new Date().getTime()));

			//
			TableQuery query = persistence.newTableQuery("PLF_USER_LOGIN", params, true);
			query.execute().update();

			//
			TableQuery dug = persistence.newTableQuery("PLF_USER_GROUP", new String[] { "username" }, params);
			dug.execute().delete();
			for (int i = 0; auth_group_list != null && i < auth_group_list.size(); i++) {
				Map map = (Map) auth_group_list.get(i);
				map.put("username", params.get("username"));
				TableQuery rtq = persistence.newTableQuery("PLF_USER_GROUP", map);
				rtq.execute().insert();
			}

			//
			TableQuery urd = persistence.newTableQuery("PLF_USER_ROLE", new String[] { "username" }, params);
			urd.execute().delete();
			for (int i = 0; auth_role_list != null && i < auth_role_list.size(); i++) {
				Map map = (Map) auth_role_list.get(i);
				map.put("username", params.get("username"));
				TableQuery rtq = persistence.newTableQuery("PLF_USER_ROLE", map);
				rtq.execute().insert();
			}
			persistence.commitTransaction();
		} catch (Exception ex) {
			throw new DatabaseException("User login insert error:" + ex.getMessage());
		} finally {
			persistence.endTransaction();
		}
	}

	/**
	 * 로그인 계정을 삭제한다.
	 * 
	 * @param params
	 * @throws DatabaseException
	 */
	public void deleteUserLogin(Map params) throws DatabaseException {
		try {

			persistence.startTransaction();

			TableQuery query = persistence.newTableQuery("PLF_USER_LOGIN", params);
			query.execute().delete();

			TableQuery dug = persistence.newTableQuery("PLF_USER_GROUP", new String[] { "username" }, params);
			dug.execute().delete();

			TableQuery urd = persistence.newTableQuery("PLF_USER_ROLE", new String[] { "username" }, params);
			urd.execute().delete();

			persistence.commitTransaction();
		} catch (Exception ex) {
			throw new DatabaseException("User login insert error:" + ex.getMessage());
		} finally {
			persistence.endTransaction();
		}
	}

	public List selectUserGroupList(Map params) throws DatabaseException {
		NamedQuery query = persistence.newNamedQuery(DAOConstants.BASE_PATH + "/UserDAO.selectUserGroupList.xml", params);
		return query.execute().selectList();
	}

	public List selectUserRoleList(Map params) throws DatabaseException {
		NamedQuery query = persistence.newNamedQuery(DAOConstants.BASE_PATH + "/UserDAO.selectUserRoleList.xml", params);
		return query.execute().selectList();
	}

}
