/*
 *  JDesigner (R) Web Application Development Platform 
 *  Copyright (C) 2010 JDesigner / SangBoo Lee (leesangboo@gmail.com)
 * 
 *  http://www.jdesigner.org/
 *  
 *  Please contact if you require licensing terms other
 *  than GPL-3 for this software.
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.jdesigner.application.template.service.config;

import java.net.URL;
import java.util.ArrayList;
import java.util.List;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.dom4j.Document;
import org.dom4j.Node;

import org.jdesigner.platform.context.ApplicationContextFactory;
import org.jdesigner.platform.scheduler.SchedulerException;
import org.jdesigner.platform.scheduler.task.SchedulerTaskInfo;
import org.jdesigner.platform.util.ClassLoaderUtil;
import org.jdesigner.platform.util.Dom4jUtils;
import org.jdesigner.platform.util.ResourceUtils;

/**
 * SchedulerTaskConfigFactory
 * 
 * @author SangBoo Lee
 * @date 2010. 3. 1.
 * @since 1.0
 * 
 */
public class SchedulerConfigurationLoader {

	private static final Log log = LogFactory.getLog(SchedulerConfigurationLoader.class);

	private static class SchedulerTaskConfigFactoryHolder {
		static SchedulerConfigurationLoader instance = new SchedulerConfigurationLoader();
	}

	public static SchedulerConfigurationLoader getInstance() {
		return SchedulerTaskConfigFactoryHolder.instance;
	}

	/**
	 * 설정파일을 로드한다.
	 * 
	 * @param filePath
	 * @return
	 * @throws SchedulerException
	 */
	public List load(String filePath) throws SchedulerException {
		try {

			//
			List taskList = new ArrayList();
			//
			log.info("Scheduler configuration xml file : path=[" + filePath + "]");

			String path = ApplicationContextFactory.getInstance().getApplicationContext().getAppPath() + filePath;
			// LOAD DOM4J

			ClassLoader classLoader = ClassLoaderUtil.getClassLoader(this.getClass());
			URL url = ResourceUtils.getURL(classLoader, path);

			Document doc = null;
			if (ResourceUtils.isJarURL(url)) {
				doc = Dom4jUtils.getXmlDocument(url);
			} else {
				doc = Dom4jUtils.getXmlDocument(ResourceUtils.extractJarFileURL(url));
			}

			//
			List schedulerTaskList = doc.selectNodes("/scheduler-config/task");
			for (int si = 0; schedulerTaskList != null && si < schedulerTaskList.size(); si++) {
				SchedulerTaskInfo info = new SchedulerTaskInfo();
				Node taskNode = (Node) schedulerTaskList.get(si);
				info.setName(taskNode.valueOf("@" + "name"));
				info.setTask(taskNode.valueOf("@" + "class"));
				info.setDelay(taskNode.valueOf("@" + "delay"));
				info.setPeriod(taskNode.valueOf("@" + "period"));
				info.setTime(taskNode.valueOf("@" + "time"));
				taskList.add(info);
			}
			return taskList;
		} catch (Exception ex) {
			throw new SchedulerException(ex);
		}
	}

}
