/*
 *  JDesigner (R) Web Application Development Platform 
 *  Copyright (C) 2010 JDesigner / SangBoo Lee (leesangboo@gmail.com)
 * 
 *  http://www.jdesigner.org/
 *  
 *  Please contact if you require licensing terms other
 *  than GPL-3 for this software.
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.jdesigner.application.template.service.impl;

import java.util.Map;

import net.sf.jsr107cache.Cache;
import net.sf.jsr107cache.CacheFactory;
import net.sf.jsr107cache.CacheManager;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import org.jdesigner.application.template.service.CacheService;
import org.jdesigner.application.template.service.CommonServiceException;

/**
 * <B>JSR 107 캐쉬 서비스 구현자</B>
 * 
 * @author leesangboo
 * 
 */
public class CacheServiceImpl implements CacheService {

	private static final Log log = LogFactory.getLog(CacheServiceImpl.class);

	public void createCache(String key, Map configuration) throws CommonServiceException {
		try {
			CacheManager singletonManager = CacheManager.getInstance();
			CacheFactory cacheFactory = singletonManager.getCacheFactory();
			Cache cache = cacheFactory.createCache(configuration);
			singletonManager.registerCache(key, cache);
			log.debug("Cache created : name=[" + key + "], configuration=[" + configuration.toString() + "]");
		} catch (Exception ex) {
			String msg = "Can not create cache : " + ex.getMessage();
			log.error(msg, ex);
			throw new CommonServiceException(msg);
		}
	}

	public Cache getCache(String key) throws CommonServiceException {
		try {
			CacheManager singletonManager = CacheManager.getInstance();
			Cache cache = singletonManager.getCache(key);
			if (cache == null) {
				throw new java.lang.IllegalStateException("Not found cache instance : name=[" + key + "]");
			}
			return cache;
		} catch (Exception ex) {
			String msg = "Can not getting cache : " + ex.getMessage();
			log.error(msg, ex);
			throw new CommonServiceException(msg);
		}
	}

}
