/*
 *  JDesigner (R) Web Application Development Platform 
 *  Copyright (C) 2010 JDesigner / SangBoo Lee (leesangboo@gmail.com)
 * 
 *  http://www.jdesigner.org/
 *  
 *  Please contact if you require licensing terms other
 *  than GPL-3 for this software.
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.jdesigner.application.template.service.impl;

import java.io.File;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.Iterator;
import java.util.List;
import java.util.Map;
import java.util.UUID;

import javax.servlet.http.HttpServletRequest;

import org.apache.commons.fileupload.FileItem;
import org.apache.commons.fileupload.FileItemFactory;
import org.apache.commons.fileupload.FileUploadException;
import org.apache.commons.fileupload.ProgressListener;
import org.apache.commons.fileupload.disk.DiskFileItemFactory;
import org.apache.commons.fileupload.servlet.ServletFileUpload;
import org.apache.commons.io.FileUtils;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import org.jdesigner.platform.util.StringUtils;
import org.jdesigner.platform.web.fileupload.MultiFileUpload;
import org.jdesigner.platform.web.fileupload.SingleFileUpload;

import org.jdesigner.application.template.dao.FileUploadDAO;
import org.jdesigner.application.template.domain.UserLogin;
import org.jdesigner.application.template.service.CommonServiceException;
import org.jdesigner.application.template.service.CommonServiceFactory;
import org.jdesigner.application.template.service.CommonServiceProperties;
import org.jdesigner.application.template.service.FileUploadService;
import org.jdesigner.application.template.service.SecurityService;

/**
 * FileUploadServiceImpl
 * 
 * @author SangBoo Lee
 * @date 2009. 11. 17.
 * @since 1.0
 * 
 */
public class FileUploadServiceImpl implements FileUploadService {

	private static final Log log = LogFactory.getLog(FileUploadServiceImpl.class);

	private static final String MULTIPART_PARAM_ENCODING = "UTF-8";

	private static final String SAVE_BASE_DIR_KEY = "service.fileupload.save.base.dir";

	private static final String TEMP_DIR_KEY = "service.fileupload.upload.temp.dir";

	private static final String MAPPING_ID_PARAM_KEY = "mapping_id";

	private FileUploadDAO dao;

	private SecurityService securityService;

	public FileUploadServiceImpl() {
		dao = new FileUploadDAO();
		securityService = CommonServiceFactory.getSecurityService();
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @seeorg.jdesigner.application.template.service.FileUploadService# createMappingID(javax.servlet.http.HttpServletRequest)
	 */
	public String createMappingID(HttpServletRequest request) throws CommonServiceException {
		String username = this.securityService.getUserLogin().getUsername();
		return username + "_" + System.currentTimeMillis() + "";
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see org.jdesigner.application.template.service.FileUploadService#upload (javax.servlet.http.HttpServletRequest)
	 */
	public List upload(HttpServletRequest request) throws CommonServiceException {

		List fileList = null;

		try {

			//
			String username = "";
			UserLogin user_login = securityService.getUserLoginFromSession((request).getSession());
			if (user_login != null && StringUtils.isNotEmpty(user_login.getUsername())) {
				username = user_login.getUsername();
			}

			log.info("File Upload Username=[" + username + "]");

			//
			boolean isMultipart = ServletFileUpload.isMultipartContent(request);

			if (!isMultipart) {
				//
			} else {

				//
				FileItemFactory factory;
				ServletFileUpload upload;

				List items = null;

				//
				try {
					//
					//Extends  Framework's BaseMultipartRequestHandler
					//BaseMultipartRequestHandler multipartHandler = new BaseMultipartRequestHandler();
					//
					request.setCharacterEncoding(MULTIPART_PARAM_ENCODING);
					//
					factory = new DiskFileItemFactory();
					//factory.setSizeThreshold(multipartHandler.getSizeThreshold());
					//factory.setRepository(multipartHandler.getRepositoryDir());
					//
					upload = new ServletFileUpload(factory);
					upload.setHeaderEncoding(request.getCharacterEncoding());
					//upload.setFileSizeMax(multipartHandler.getMaxFileSize());
					//upload.setSizeMax(multipartHandler.getSizeMax());
					//Create a progress listener
					ProgressListener progressListener = new ProgressListener() {
						private long megaBytes = -1;

						public void update(long pBytesRead, long pContentLength, int pItems) {
							long mBytes = pBytesRead / 1000;
							if (megaBytes == mBytes) {
								return;
							}
							megaBytes = mBytes;
							log.debug("File upload currently reading item " + pItems);
							if (pContentLength == -1) {
								log.debug("File progressing, " + pBytesRead + " bytes have been read.");
							} else {
								log.debug("File progressing, " + pBytesRead + " of " + pContentLength + " bytes have been read.");
							}
						}
					};
					upload.setProgressListener(progressListener);
					//
					items = upload.parseRequest(request);

				} catch (FileUploadException e) {
					log.error("File items getting error : " + e.toString());
					throw e;
				}

				//
				String mappingID = "";
				Iterator mappingitr = items.iterator();
				while (mappingitr.hasNext()) {
					FileItem item = (FileItem) mappingitr.next();
					if (item.isFormField()) {
						if (item.getFieldName().equals(MAPPING_ID_PARAM_KEY)) {
							mappingID = item.getString();
							break;
						}
					}
				}

				//
				if (mappingID == null || mappingID.equals("")) {
					throw new CommonServiceException("Not found mapping_id parameter.");
				}

				//
				String tempDir = getTempBaseDirPath() + mappingID + "/";

				//
				File tempDirFile = new File(tempDir);
				if (!tempDirFile.exists()) {
					tempDirFile.mkdir();
				}

				//
				Iterator itr = items.iterator();
				while (itr.hasNext()) {
					FileItem item = (FileItem) itr.next();
					if (item.isFormField()) {
						//
					} else {
						try {

							//
							Map params = new HashMap();
							params.put("username", username);
							params.put("mapping_id", mappingID);
							params.put("temp_dir", tempDir);
							params.put("temp_file_name", item.getName());
							params.put("file_content_type", item.getContentType());
							params.put("file_size", new Long(item.getSize()));

							//
							String tempFileName = item.getName();
							File tempFile = new File(tempDir + tempFileName);
							item.write(tempFile);

							//
							dao.insertFileUploadHistory(params);

							//
							log.info("File uploaded : path=[" + tempDir + tempFileName + "]");

						} catch (Exception e) {
							log.error("File items write error : " + e.getMessage());
							throw new FileUploadException(e.getMessage());
						}
					}
				}
			}
		} catch (Exception ex) {
			String msg = "File upload service temp upload error : " + ex.getMessage();
			log.error(msg, ex);
			throw new CommonServiceException(msg, ex);
		}
		return fileList;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see org.jdesigner.application.template.service.FileUploadService#saveSingleFile(org.jdesigner.platform.web.fileupload.SingleFileUpload,
	 * java.lang.String)
	 */
	public Map saveSingleFile(SingleFileUpload upload, String outDirectory) throws CommonServiceException {
		return saveSingleFile(upload.getMappingID(), upload.getFileName(), outDirectory);
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see org.jdesigner.application.template.service.FileUploadService#saveMultiFile(org.jdesigner.platform.web.fileupload.MultiFileUpload,
	 * java.lang.String)
	 */
	public List saveMultiFile(MultiFileUpload upload, String outDirectory) throws CommonServiceException {
		return saveMultiFile(upload.getMappingID(), upload.getFileNames(), outDirectory);
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @seeorg.jdesigner.application.template.service.FileUploadService# saveSingleFile(javax.servlet.http.HttpServletRequest, java.lang.String,
	 * java.lang.String, java.lang.String)
	 */
	public Map saveSingleFile(String mappingID, String tempFileName, String outDirectory) throws CommonServiceException {
		List result = saveMultiFile(mappingID, new String[] { tempFileName }, outDirectory);
		return (result != null && result.size() > 0) ? (Map) result.get(0) : null;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see org.jdesigner.application.template.service.FileUploadService#save( javax.servlet.http.HttpServletRequest, java.lang.String,
	 * java.lang.String[], java.lang.String)
	 */
	public List saveMultiFile(String mappingID, String[] tempFileNames, String outDirectory) throws CommonServiceException {
		List savedList = null;

		try {

			//
			String username = "";

			//securityService.bind(request.getSession());

			if (securityService.isUserAuthenticated()) {
				username = securityService.getUserLogin().getUsername();
			}

			//
			if (outDirectory == null || outDirectory.equals("")) {
				outDirectory = CommonServiceProperties.getString(SAVE_BASE_DIR_KEY);
			}

			//
			if (tempFileNames != null && tempFileNames.length > 0) {
				savedList = new ArrayList();
				for (int i = 0; i < tempFileNames.length; i++) {
					String tempDir = getTempBaseDirPath() + mappingID + "/";
					if (tempFileNames[i] != null && !tempFileNames[i].equals("")) {
						//
						String encodeTemptFileName = tempFileNames[i];
						String temptFileName = tempFileNames[i];
						String outFileName = generateSaveFileName(encodeTemptFileName, mappingID);
						File tempFile = new File(tempDir, temptFileName);
						if (!tempFile.exists()) {
							//throw new CommonServiceException("Not found uploaded temp file : path=[" + tempDir + "/" +  temptFileName + "]");
							log.info("Not found uploaded temp file : path=[" + tempDir + temptFileName + "]");

							return null;
						}
						;

						//
						try {
							File outDir = new File(outDirectory);
							if (!outDir.exists()) {
								outDir.mkdir();
							}
							//
							File saveFile = new File(outDir, outFileName);
							FileUtils.copyFile(tempFile, saveFile);
							// FileUtils.copyFileToDirectory(tempFile, outDir);
						} catch (Exception ex) {
							throw new CommonServiceException("Temp file copy to output directory error : " + ex.getMessage(), ex);
						}
						;

						//
						Map params = new HashMap();
						params.put("username", username);
						params.put("mapping_id", mappingID);
						params.put("temp_dir", tempDir);
						params.put("temp_file_name", encodeTemptFileName);
						params.put("save_dir", outDirectory);
						params.put("save_file_name", outFileName);
						params.put("display_file_name", encodeTemptFileName);

						//
						Map saveFileMap = dao.updateFileUploadHistory(params);

						//
						// File savedFile = new File(outDirectory,
						// targetFileName);
						// saveFileMap.put("saved_file", savedFile);

						//
						savedList.add(saveFileMap);

						log.info("File saved : outDirectory=[" + outDirectory + "], displayFileName=[" + encodeTemptFileName + "], saveFileName=[" + outFileName + "] ");
					}
				}
			} else {
				log.info("Not found upload target files .");
			}
		} catch (Exception ex) {
			String msg = "File upload service save error : " + ex.getMessage();
			log.error(msg, ex);
			throw new CommonServiceException(msg, ex);
		}
		return savedList;
	}

	/**
	 * JAVA TEMP 디렉토리 경로를 반환한다.
	 * 
	 * @return
	 */
	public String getTempBaseDirPath() throws CommonServiceException {
		String tempDir = "";
		// ServletContext context = request.getSession().getServletContext();

		//
		tempDir = CommonServiceProperties.getString(TEMP_DIR_KEY);

		//
		if (tempDir == null || tempDir.equals("")) {
			/*
			 * if (context != null) { File tempDirFile = (File) context.getAttribute("javax.servlet.context.tempdir"); tempDir =
			 * tempDirFile.getAbsolutePath(); } if ((tempDir == null) || (tempDir.length() == 0)) { tempDir = System.getProperty("java.io.tmpdir"); }
			 */
			throw new CommonServiceException("Not cofigure temp dir path.");
		}

		//
		tempDir = StringUtils.cleanPath(tempDir) + "/";

		//
		File dir = new File(tempDir);
		if (!(dir).exists()) {
			dir.mkdir();
		}

		//
		if (log.isTraceEnabled()) {
			log.trace("File upload temp dir: " + tempDir);
		}

		return tempDir;
	}

	/**
	 * 저장될 파일명을 생성한다.
	 * 
	 * @param temptFileName
	 * @param mappingID
	 * @return
	 * @throws Exception
	 */
	private static String generateSaveFileName(String temptFileName, String mappingID) throws Exception {
		// String prefix = temptFileName.substring(0,
		// temptFileName.lastIndexOf("."));
		String suffix = temptFileName.substring(temptFileName.lastIndexOf("."));
		String uuid = UUID.randomUUID().toString().toUpperCase();
		return mappingID + "_" + uuid + suffix;
	}

}
