/*
 *  JDesigner (R) Web Application Development Platform 
 *  Copyright (C) 2010 JDesigner / SangBoo Lee (leesangboo@gmail.com)
 * 
 *  http://www.jdesigner.org/
 *  
 *  Please contact if you require licensing terms other
 *  than GPL-3 for this software.
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.jdesigner.application.template.web.filter;

import java.io.IOException;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import javax.servlet.Filter;
import javax.servlet.FilterChain;
import javax.servlet.FilterConfig;
import javax.servlet.ServletException;
import javax.servlet.ServletRequest;
import javax.servlet.ServletResponse;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpSession;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import org.jdesigner.platform.async.AsynchronousExecutor;
import org.jdesigner.platform.async.Worker;
import org.jdesigner.platform.util.MapUtils;

import org.jdesigner.application.template.service.AnalysisService;
import org.jdesigner.application.template.service.CommonServiceFactory;
import org.jdesigner.application.template.service.SecurityService;
import org.jdesigner.application.template.service.factory.AccessAnalysisLogBufferFactory;

/**
 * AccessAnalysisFilter
 * 
 * @author leesangboo
 * 
 */
public class AccessAnalysisFilter implements Filter {

	private static final Log log = LogFactory.getLog(AccessAnalysisFilter.class);

	private static final String BUFFER_KEY = "buffer";

	private static final int DEFUALT_BUFFER_SIZE = 100;

	private static final int MAX_QUERY_CHAR_LENGTH = 10000;

	private int bufferSize = 0;

	public void init(FilterConfig config) throws ServletException {
		//
		bufferSize = config.getInitParameter(BUFFER_KEY) != null ? Integer.parseInt(config.getInitParameter(BUFFER_KEY)) : DEFUALT_BUFFER_SIZE;
	}

	public void destroy() {
		//
	}

	public void doFilter(ServletRequest srequest, ServletResponse sresponse, FilterChain chain) throws IOException, ServletException {
		HttpServletRequest request = (HttpServletRequest) srequest;
		HttpSession session = request.getSession();

		try {
			//
			SecurityService securityService = CommonServiceFactory.getSecurityService();
			//securityService.bind(session);

			//
			String username = "";
			if (securityService.isUserAuthenticated()) {
				username = securityService.getUserLogin().getUsername();
			}
			log.debug("Page access user = [" + username + "]");
			String ip = request.getRemoteAddr();
			String uri = request.getRequestURI();
			// String query = request.getQueryString();
			String query = MapUtils.parameterToString(request.getParameterMap());

			String agent = request.getHeader("User-Agent");
			String language = request.getLocale().getLanguage();
			String jsession_id = session.getId();

			//
			final Map params = new HashMap();
			params.put("username", username);
			params.put("ip", ip);
			params.put("uri", uri);
			params.put("query", (query != null && !query.equals("") && query.length() > MAX_QUERY_CHAR_LENGTH) ? query.substring(0, MAX_QUERY_CHAR_LENGTH) : query);
			params.put("agent", agent);
			params.put("language", language);
			params.put("jsession_id", jsession_id);

			//
			AccessAnalysisLogBufferFactory bufferFactory = AccessAnalysisLogBufferFactory.getInstance();
			bufferFactory.addBuffer(params);

			if (bufferFactory.getBufferSize() == bufferSize) {
				//
				final List bufferList = bufferFactory.getBufferList();
				bufferFactory.resetBufferList();
				//
				AsynchronousExecutor executor = new AsynchronousExecutor();
				executor.execute(new Worker() {
					public void execute() {
						for (int i = 0; i < bufferList.size(); i++) {
							Map buffer = (Map) bufferList.get(i);
							AnalysisService service = CommonServiceFactory.getAnalysisService();
							service.insertAccessAnalysis(buffer);
						}
					}
				});
			}

			// move on to the next
			chain.doFilter(srequest, sresponse);

		} catch (Exception ex) {
			log.error("Access analysis filter error : " + ex.getMessage(), ex);
			throw new ServletException(ex);
		}
	}

}
