/*
 *  JDesigner (R) Web Application Development Platform 
 *  Copyright (C) 2010 JDesigner / SangBoo Lee (leesangboo@gmail.com)
 * 
 *  http://www.jdesigner.org/
 *  
 *  Please contact if you require licensing terms other
 *  than GPL-3 for this software.
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.jdesigner.application.template.web.filter;

import java.io.IOException;

import javax.servlet.Filter;
import javax.servlet.FilterChain;
import javax.servlet.FilterConfig;
import javax.servlet.ServletException;
import javax.servlet.ServletRequest;
import javax.servlet.ServletResponse;
import javax.servlet.http.HttpServletRequest;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import org.jdesigner.application.template.service.CommonServiceFactory;
import org.jdesigner.application.template.service.SecurityService;

/**
 * 자동 로그인 필터
 * 
 * @author leesangboo
 * 
 */
public class AutoLoginFilter implements Filter {

	private static final Log log = LogFactory.getLog(AutoLoginFilter.class);

	private String username = "";
	private String password = "";

	public void init(FilterConfig config) throws ServletException {
		username = config.getInitParameter("username");
		password = config.getInitParameter("password");
		//
	}

	public void destroy() {
		//
	}

	public void doFilter(ServletRequest srequest, ServletResponse sresponse, FilterChain chain) throws IOException, ServletException {

		HttpServletRequest request = (HttpServletRequest) srequest;

		try {

			SecurityService securityService = CommonServiceFactory.getSecurityService();
			//securityService.bind(session);

			if (!securityService.isUserAuthenticated()) {
				securityService.login(request.getSession(), request.getRemoteAddr(), username, password);
				securityService.getLoginEventListener().afterLoginSuccess(request, username);
				log.info("Logined from AutoLoginFilter.");
			}

			// move on to the next
			chain.doFilter(srequest, sresponse);

		} catch (Exception ex) {
			log.error("Auto login filter error : " + ex.getMessage(), ex);
			throw new ServletException(ex);
		}
	}

}
