/*
 *  JDesigner (R) Web Application Development Platform 
 *  Copyright (C) 2010 JDesigner / SangBoo Lee (leesangboo@gmail.com)
 * 
 *  http://www.jdesigner.org/
 *  
 *  Please contact if you require licensing terms other
 *  than GPL-3 for this software.
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.jdesigner.application.template.web.login;

import javax.servlet.http.HttpSession;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.apache.struts.action.ActionErrors;
import org.apache.struts.action.ActionMessage;

import org.jdesigner.application.template.service.CommonServiceFactory;
import org.jdesigner.application.template.service.LoginEventListener;
import org.jdesigner.application.template.service.SecurityService;
import org.jdesigner.application.template.web.TemplateBaseActionBean;

/**
 * <B>Login Bean</B>
 * 
 * @author leesangboo
 * 
 */
public class LoginBean extends TemplateBaseActionBean {

	private static final long serialVersionUID = 1L;

	private static final Log log = LogFactory.getLog(LoginBean.class);

	// ---------------------------------------------------------------------------------------
	// BUSINESS SERVICE
	// ---------------------------------------------------------------------------------------
	private SecurityService securityService;

	// ---------------------------------------------------------------------------------------
	// INPUT VARIABLE
	// ---------------------------------------------------------------------------------------
	private String username;
	private String password;

	// ---------------------------------------------------------------------------------------
	// CONSTRUCTURE
	// ---------------------------------------------------------------------------------------
	public LoginBean() {
		this.securityService = CommonServiceFactory.getSecurityService();
	}

	// ---------------------------------------------------------------------------------------
	// WEB METHODS
	// ---------------------------------------------------------------------------------------

	/** 로그인을 실행한다. */
	public String login() throws Exception {

		log.debug("LoginAction : username=[" + username + "], password=[" + password + "]");

		//
		//HttpSession session = super.getActionBeanContext().getRequest().getSession();
		String ip = super.getActionBeanContext().getRequest().getRemoteAddr();
		ActionErrors errors = super.getActionErrors();

		//
		LoginEventListener listener = securityService.getLoginEventListener();
		listener.beforeLogin(super.getActionBeanContext().getRequest());

		//
		boolean isLogin = this.securityService.login(super.getRequest().getSession(), ip, username, password);

		if (isLogin) {

			listener.afterLoginSuccess(super.getActionBeanContext().getRequest(), username);

			//
			return (SUCCESS);

		} else {

			listener.afterLoginFailure(super.getActionBeanContext().getRequest());

			this.password = ""; //
			errors.add(GLOBAL_ERROR, new ActionMessage("login.title.failed"));
			return (FORM);
		}
	}

	/** 로그아웃을 실행한다. */
	public String logout() throws Exception {
		//
		LoginEventListener listener = securityService.getLoginEventListener();
		//
		HttpSession session = super.getRequest().getSession();
		//
		listener.beforLogout(super.getActionBeanContext().getRequest());
		//
		this.securityService.logout(session);
		//
		listener.afterLogout(super.getActionBeanContext().getRequest());
		//
		return (SUCCESS);
	}

	public String getPassword() {
		return password;
	}

	public void setPassword(String password) {
		this.password = password;
	}

	public String getUsername() {
		return username;
	}

	public void setUsername(String username) {
		this.username = username;
	}

}