/*
 *  JDesigner (R) Web Application Development Platform 
 *  Copyright (C) 2010 JDesigner / SangBoo Lee (leesangboo@gmail.com)
 * 
 *  http://www.jdesigner.org/
 *  
 *  Please contact if you require licensing terms other
 *  than GPL-3 for this software.
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.jdesigner.application.template.web.system;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import org.jdesigner.platform.web.form.Form;
import org.jdesigner.platform.web.form.FormMode;
import org.jdesigner.platform.web.grid.Grid;
import org.jdesigner.platform.web.json.JSONResult;

import org.jdesigner.application.template.service.CommonServiceFactory;
import org.jdesigner.application.template.service.NoticeService;
import org.jdesigner.application.template.web.TemplateBaseActionBean;

/**
 * NoticeMngBean
 * @author leesangboo
 *
 */
public class NoticeMngBean extends TemplateBaseActionBean {

	private static final Log log = LogFactory.getLog(NoticeMngBean.class);

	private static final long serialVersionUID = 1L;

	private Form search;
	private Form form;
	private Grid grid;
	private JSONResult json;

	private NoticeService notice_service;

	public NoticeMngBean() {
		init(); //
	}

	public void init() {
		log.info("ActionBean[" + this.getClass() + "] initialize...");
		//
		form = new Form();
		search = new Form();
		grid = new Grid();
		json = new JSONResult();
		//
		notice_service = CommonServiceFactory.getNoticeService();
	}

	public void reset() {

	}

	public String index() throws Exception {
		reset();
		return SUCCESS;
	}

	public String grid() throws Exception {
		grid = new Grid(notice_service.selectNoticePage(search, grid.getStart(), grid.getRange(), grid.getSort(), grid.isDesc()));
		return Grid.FORWARD;
	}

	public String add() throws Exception {
		form.setMode(FormMode.INSERT);
		return SUCCESS;
	}

	public String edit() throws Exception {
		form.setMode(FormMode.UPDATE);
		form.putAll(notice_service.selectNoticeMap(form));
		return SUCCESS;
	}

	public String insert() throws Exception {
		notice_service.insertNotice(form);
		setServerMessage("common.insert.success");
		reset();
		return SUCCESS;
	}

	public String update() throws Exception {
		notice_service.updateNotice(form);
		setServerMessage("common.update.success");
		return SUCCESS;
	}

	public String delete() throws Exception {
		notice_service.deleteNotice(form);
		setServerMessage("common.delete.success");
		return SUCCESS;
	}

	public NoticeService getNotice_service() {
		return notice_service;
	}

	public void setNotice_service(NoticeService portletService) {
		notice_service = portletService;
	}

	public Form getForm() {
		return form;
	}

	public void setForm(Form form) {
		this.form = form;
	}

	public Grid getGrid() {
		return grid;
	}

	public void setGrid(Grid grid) {
		this.grid = grid;
	}

	public JSONResult getJson() {
		return json;
	}

	public void setJson(JSONResult json) {
		this.json = json;
	}

	public Form getSearch() {
		return search;
	}

	public void setSearch(Form search) {
		this.search = search;
	}

}