/*
 *  JDesigner (R) Web Application Development Platform 
 *  Copyright (C) 2010 JDesigner / SangBoo Lee (leesangboo@gmail.com)
 * 
 *  http://www.jdesigner.org/
 *  
 *  Please contact if you require licensing terms other
 *  than GPL-3 for this software.
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.jdesigner.application.template.web.system;

import java.util.HashMap;
import java.util.Map;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import org.jdesigner.application.template.domain.UIState;
import org.jdesigner.application.template.web.TemplateBaseActionBean;
import org.jdesigner.application.template.web.WebKeys;

/**
 * 
 * UI 상태 저장 액션 빈
 * 
 * @author leesangboo
 * 
 */
public class UIStateStoreBean extends TemplateBaseActionBean {

	private static final long serialVersionUID = 1L;

	private static final Log log = LogFactory.getLog(UIStateStoreBean.class);

	// ---------------------------------------------------------------------------------------
	// BUSINESS SERVICE
	// ---------------------------------------------------------------------------------------

	// ---------------------------------------------------------------------------------------
	// INPUT VARIABLE
	// ---------------------------------------------------------------------------------------
	private String pageURL;
	private String componentID;
	private String state;

	// ---------------------------------------------------------------------------------------
	// CONSTRUCTURE
	// ---------------------------------------------------------------------------------------
	public UIStateStoreBean() {
		init(); //
	}

	private void init() {
		pageURL = "";
		componentID = "";
		state = "";
	}

	// ---------------------------------------------------------------------------------------
	// WEB METHODS
	// ---------------------------------------------------------------------------------------
	public String save() throws Exception {
		getUIStateMap().put(getUniqueID(), state);
		setUIStateMap(getUniqueID(), new UIState(pageURL, componentID, state));
		log.debug("UI State [" + getUniqueID() + "] saved.");
		return (NULL);
	}

	public String remove() throws Exception {
		log.debug("UI State [" + getUniqueID() + "] removed.");
		return (NULL);
	}

	// ---------------------------------------------------------------------------------------
	// SUPPORT METHODS
	// ---------------------------------------------------------------------------------------
	private String getUniqueID() {
		return pageURL + "#" + componentID;
	}

	private Map getUIStateMap() {
		Map store = (Map) getRequest().getSession().getAttribute(WebKeys.UI_STATE_STORE_KEY);
		if (store == null) {
			store = new HashMap();
			getRequest().getSession().setAttribute(WebKeys.UI_STATE_STORE_KEY, store);
		}
		return store;
	}

	private void setUIStateMap(String key, UIState uiState) {
		Map store = (Map) getRequest().getSession().getAttribute(WebKeys.UI_STATE_STORE_KEY);
		if (store == null) {
			store = new HashMap();
		}
		store.put(key, uiState);
		getRequest().getSession().setAttribute(WebKeys.UI_STATE_STORE_KEY, store);
	}

	// ---------------------------------------------------------------------------------------
	// RESET
	// ---------------------------------------------------------------------------------------
	public void reset() {

	}

	// ---------------------------------------------------------------------------------------
	// CLEAR
	// ---------------------------------------------------------------------------------------
	public void clear() {
		log.info("Clear Action Bean Variables : " + this.getClass().getName());
	}

	// ---------------------------------------------------------------------------------------
	// GETTER & SETTER
	// ---------------------------------------------------------------------------------------
	public String getComponentID() {
		return componentID;
	}

	public void setComponentID(String componentID) {
		this.componentID = componentID;
	}

	public String getPageURL() {
		return pageURL;
	}

	public void setPageURL(String pageURL) {
		this.pageURL = pageURL;
	}

	public String getState() {
		return state;
	}

	public void setState(String state) {
		this.state = state;
	}

}