/*
 * JDesigner (R) Web Application Development Platform 
 * Copyright (C) 2010 JDesigner / SangBoo Lee (leesangboo@gmail.com)
 * 
 * http://www.jdesigner.org/
 *  
 *  Please contact if you require licensing terms other
 *  than GPL-3 for this software.
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package org.jdesigner.platform.cache.impl;

import java.util.Collections;
import java.util.HashMap;
import java.util.LinkedList;
import java.util.List;
import java.util.Map;
import java.util.Properties;

import org.jdesigner.platform.cache.Cache;
import org.jdesigner.platform.cache.CacheException;

/**
 * FIFOCache
 * 
 * @author leesangboo
 * 
 */
public class FIFOCache implements Cache {

	private static final long serialVersionUID = 1L;

	private int cacheSize = 100;

	private Map cache = Collections.synchronizedMap(new HashMap());

	private List keyList = Collections.synchronizedList(new LinkedList());

	public static final String CONFIG_CACHE_SIZE_KEY = "cache-size";

	public FIFOCache() {
		//
	}

	public FIFOCache(Properties configuration) {
		if (configuration != null) {
			int cacheSize = Integer.parseInt(configuration.getProperty(CONFIG_CACHE_SIZE_KEY));
			this.cacheSize = cacheSize;
		}
	}

	public Object get(String key) throws CacheException {
		return cache.get(key);
	}

	public boolean hasValue(String key) throws CacheException {
		Object o = cache.get(key);
		if (o == null && !cache.containsKey(key)) {
			return false;
		} else {
			return true;
		}
	}

	public void remove(String key) throws CacheException {
		keyList.remove(key);
		cache.remove(key);
	}

	public void put(String key, Object value) throws CacheException {
		cache.put(key, value);
		keyList.add(key);
		if (keyList.size() > cacheSize) {
			try {
				Object oldestKey = keyList.remove(0);
				cache.remove(oldestKey);
			} catch (IndexOutOfBoundsException e) {
				//ignore
			}
		}
	}

	public void flush() throws CacheException {
		cache.clear();
	}

	public Map toMap() throws CacheException {
		return cache;
	}

}
