/*
 * JDesigner (R) Web Application Development Platform 
 * Copyright (C) 2010 JDesigner / SangBoo Lee (leesangboo@gmail.com)
 * 
 * http://www.jdesigner.org/
 *  
 *  Please contact if you require licensing terms other
 *  than GPL-3 for this software.
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package org.jdesigner.platform.context;

import java.util.Properties;

import org.jdesigner.platform.util.PropertiesUtils;

/**
 * ApplicationConfig
 * 
 * @author leesangboo
 * 
 */
public class ApplicationConfig {

	public static final String PLATFORM_PROPERTIES_FILENAME = "platform.properties";

	private Properties properties;

	public ApplicationConfig() {
		initialize(); //
	}

	private void initialize() {
		PropertiesUtils propertiesUtils = new PropertiesUtils(PLATFORM_PROPERTIES_FILENAME);
		properties = propertiesUtils.getProperties();
	}

	public String getProperty(String key) {
		if (!properties.containsKey(key)) {
			throw new RuntimeException("Not found application config properties key : " + key);
		}
		return properties.getProperty(key);
	}

	public String getString(String key) {
		return properties.getProperty(key);
	}

	public int getInt(String key) {
		return Integer.valueOf(getString(key)).intValue();
	}

	public long getLong(String key) {
		return Long.valueOf(getString(key)).longValue();
	}

	public boolean getBoolean(String key) {
		return Boolean.valueOf(getString(key)).booleanValue();
	}

	public Properties getProperties() {
		return properties;
	}

}
