/*
 * JDesigner (R) Web Application Development Platform 
 * Copyright (C) 2010 JDesigner / SangBoo Lee (leesangboo@gmail.com)
 * 
 * http://www.jdesigner.org/
 *  
 *  Please contact if you require licensing terms other
 *  than GPL-3 for this software.
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package org.jdesigner.platform.context;

import java.util.Date;

import javax.servlet.ServletContext;
import javax.servlet.ServletContextEvent;
import javax.servlet.ServletContextListener;

import org.jdesigner.platform.Metadata;
import org.jdesigner.platform.util.StringUtils;

/**
 * <B> ApplicationContextListener </B>
 * 
 * @author leesangboo
 * 
 */
public final class ApplicationContextListener implements ServletContextListener {

	private static final String NEW_LINE = System.getProperty("line.separator");

	/**
	 * 어플리케이션 컨텍스트 키
	 */
	public static final String APPLICATION_CONTEXT_KEY = "application.context";

	/*
	 * (non-Javadoc)
	 * 
	 * @see javax.servlet.ServletContextListener#contextInitialized(javax.servlet .ServletContextEvent)
	 */
	public void contextInitialized(ServletContextEvent servletContextEvent) {
		ServletContext servletContext = servletContextEvent.getServletContext();

		try {
			//
			ApplicationConfig applicationConfig = new ApplicationConfig();

			//
			String scName = servletContext.getServletContextName();
			// String conPath = servletContext.getContextPath();
			String wasName = servletContext.getServerInfo();
			String appPath = StringUtils.cleanPath(servletContext.getRealPath("/"));
			String servletVersion = servletContext.getMajorVersion() + "." + servletContext.getMinorVersion();

			//
			ApplicationContext applicationContext = new ApplicationContext(applicationConfig, wasName, appPath, servletVersion);
			applicationContext.setStartDate(new Date());
			ApplicationContextFactory factory = ApplicationContextFactory.getInstance();
			factory.setApplicationContext(applicationContext);

			//
			servletContext.setAttribute(APPLICATION_CONTEXT_KEY, applicationContext);

			//
			System.out.println("");
			System.out.println("#=======================================================================================================");
			System.out.println("# " + Metadata.PLATFORM_NAME + "  (" + Metadata.PLATFORM_VERSION + ") Initialized.");
			System.out.println("#-------------------------------------------------------------------------------------------------------");
			System.out.println("# Web application = [" + scName + "]");
			System.out.println("# Web application server name = [" + wasName + "]");
			System.out.println("# Web application servlet version = [" + servletVersion + "]");
			System.out.println("# Web application path = [" + appPath + "]");
			System.out.println("# Copyright 2003-2009 JDesigner, Inc / All rights reserved.   ");
			System.out.println("#-------------------------------------------------------------------------------------------------------");

		} catch (Exception e) {
			System.out.println("Couldn't create ApplicationContext attribute : " + e.getMessage());
			e.printStackTrace(System.err);
		}
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @seejavax.servlet.ServletContextListener#contextDestroyed(javax.servlet. ServletContextEvent)
	 */
	public void contextDestroyed(ServletContextEvent servletContextEvent) {
		//
		ServletContext servletContext = servletContextEvent.getServletContext();
		String scName = servletContext.getServletContextName();
		servletContext.removeAttribute(APPLICATION_CONTEXT_KEY);
		//
		System.out.println("# Web Application = [" + scName + "] : " + Metadata.PLATFORM_NAME + "  (" + Metadata.PLATFORM_VERSION + ") Destroyed." + NEW_LINE + NEW_LINE + NEW_LINE);
	}

}
