/*
 * JDesigner (R) Web Application Development Platform 
 * Copyright (C) 2010 JDesigner / SangBoo Lee (leesangboo@gmail.com)
 * 
 * http://www.jdesigner.org/
 *  
 *  Please contact if you require licensing terms other
 *  than GPL-3 for this software.
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package org.jdesigner.platform.data;

import java.util.List;

import org.apache.commons.lang.builder.ToStringBuilder;

/**
 * <B>Page</B>
 * 
 * 
 * @author leesangboo
 * 
 */
public class Page {

	public static final String PAGE_START_PARAM_KEY = "page_start";

	public static final String PAGE_END_PARAM_KEY = "page_end";

	private int start; // 시작 페이지

	private int range; // 1페이지당 아이템 사이즈

	private long count; // 조회된 전체 아이템 갯수

	private String sort; // 정렬할 컬럼

	private boolean desc; // 역정렬 여부

	private List list; // 페이징된 목록

	/**
	 * Page 생성자
	 * 
	 * @param start
	 * @param range
	 */
	public Page(int start, int range) {
		super();
		this.start = start;
		this.range = range;
	}

	/**
	 * Page 생성자
	 * 
	 * @param start
	 * @param range
	 * @param sort
	 * @param desc
	 */
	public Page(int start, int range, String sort, boolean desc) {
		super();
		this.start = start;
		this.range = range;
		this.sort = sort;
		this.desc = desc;
	}

	/**
	 * Page 생성자
	 * 
	 * @param count
	 *            - 조회된 전체 아이템 갯수
	 * @param list
	 *            - 페이징된 목록
	 * @param start
	 *            - 시작 페이지
	 * @param range
	 *            - 1페이지당 아이템 사이즈
	 */
	public Page(long count, List list, int start, int range) {
		super();
		this.count = count;
		this.list = list;
		this.start = start;
		this.range = range;
	}

	/**
	 * Page 생성자
	 * 
	 * @param count
	 *            - 조회된 전체 아이템 갯수
	 * @param list
	 *            - 페이징된 목록
	 * @param start
	 *            - 시작 페이지
	 * @param range
	 *            - 1페이지당 아이템 사이즈
	 * @param sort
	 *            - 정렬할 컬럼
	 * @param desc
	 *            - 역정렬 여부
	 */
	public Page(long count, List list, int start, int range, String sort, boolean desc) {
		super();
		this.count = count;
		this.list = list;
		this.start = start;
		this.range = range;
		this.sort = sort;
		this.desc = desc;
	}

	public long getCount() {
		return count;
	}

	public void setCount(long count) {
		this.count = count;
	}

	public List getList() {
		return list;
	}

	public void setList(List list) {
		this.list = list;
	}

	public int getStart() {
		return start;
	}

	public void setStart(int start) {
		this.start = start;
	}

	public int getRange() {
		return range;
	}

	public void setRange(int size) {
		this.range = size;
	}

	public String getSort() {
		return sort;
	}

	public void setSort(String sort) {
		this.sort = sort;
	}

	public boolean isDesc() {
		return desc;
	}

	public void setDesc(boolean desc) {
		this.desc = desc;
	}

	public String toString() {
		return ToStringBuilder.reflectionToString(this);
	}

}
