/*
 *  JDesigner (R) Web Application Development Platform 
 *  Copyright (C) 2010 JDesigner / SangBoo Lee (leesangboo@gmail.com)
 * 
 *  http://www.jdesigner.org/
 *  
 *  Please contact if you require licensing terms other
 *  than GPL-3 for this software.
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.jdesigner.platform.db;

/**
 * PersistenceContext
 * 
 * @author leesangboo
 * 
 */
public class PersistenceContext {

	public static ThreadLocal local = new ThreadLocal();

	public static PersistenceMap get() {
		return (PersistenceMap) local.get();
	}

	public static void set(PersistenceMap persistenceMap) {
		local.set(persistenceMap);
	}

	public static Persistence getPersistence(String id) {
		PersistenceMap persistenceMap = get();
		if (persistenceMap == null) {
			persistenceMap = new PersistenceMap();
			set(persistenceMap);
		}
		return persistenceMap.get(id);
	}

	public static void addPersistence(String id, Persistence persistence) {
		PersistenceMap persistenceMap = get();
		if (persistenceMap == null) {
			persistenceMap = new PersistenceMap();
			set(persistenceMap);
		}
		persistenceMap.set(id, persistence);
		set(persistenceMap);
	}

	public static void removePersistence(String id) {
		PersistenceMap persistenceMap = get();
		if (persistenceMap == null) {
			persistenceMap = new PersistenceMap();
			set(persistenceMap);
		}
		persistenceMap.remove(id);
		set(persistenceMap);
	}

}
