/*
 * JDesigner (R) Web Application Development Platform 
 * Copyright (C) 2010 JDesigner / SangBoo Lee (leesangboo@gmail.com)
 * 
 * http://www.jdesigner.org/
 *  
 *  Please contact if you require licensing terms other
 *  than GPL-3 for this software.
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package org.jdesigner.platform.db.connection;

import java.sql.Connection;

import javax.sql.DataSource;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import org.jdesigner.platform.context.ApplicationConfigUtils;
import org.jdesigner.platform.jndi.JDBCDataSourceServiceLocator;

/**
 * ConnectionManager
 * 
 * @author leesangboo
 * 
 */
public final class ConnectionManager {

	private static final Log log = LogFactory.getLog(ConnectionManager.class);

	private static final String DATASOURCE_NAME_KEY = "platform.db.datasource.jndi";

	/**
	 * 데이터베이스 커넥션을 반환한다.
	 * 
	 * @return
	 * @throws ConnectionException
	 */
	public Connection getConnection() throws ConnectionException {
		return getConnection(ApplicationConfigUtils.getProperty(DATASOURCE_NAME_KEY));

	}

	/**
	 * 데이터베이스 커넥션을 반환한다.
	 * 
	 * @param dataSourceJNDIName
	 * @return
	 * @throws ConnectionException
	 */
	public Connection getConnection(String dataSourceJNDIName) throws ConnectionException {
		Connection connection = null;
		try {
			JDBCDataSourceServiceLocator jdbcSerLoc = JDBCDataSourceServiceLocator.getInstance();
			DataSource dataSource = jdbcSerLoc.getDataSource(dataSourceJNDIName);
			connection = dataSource.getConnection();
			if (connection == null) {
				throw new ConnectionException("JDBC connection is NULL");
			}
			return connection;
		} catch (Exception e) {
			String msg = "Error opening JDBC connection : " + e.getMessage();
			log.error(msg, e);
			throw new ConnectionException(msg, e);
		}
	}

}
