/*
 *  JDesigner (R) Web Application Development Platform 
 *  Copyright (C) 2010 JDesigner / SangBoo Lee (leesangboo@gmail.com)
 * 
 *  http://www.jdesigner.org/
 *  
 *  Please contact if you require licensing terms other
 *  than GPL-3 for this software.
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package org.jdesigner.platform.db.connection;

import java.sql.Connection;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.sql.Statement;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

/**
 * <B>Connection Utils</B>
 * 
 * @author leesangboo
 * 
 */
public class ConnectionUtils {

	private static final Log log = LogFactory.getLog(ConnectionUtils.class);

	/**
	 * 데이터베이스 자원을 해제 한다.
	 * 
	 * @param conn
	 * @param stmnt
	 * @param rst
	 * @deprecated
	 */
	public static void cleanup(Connection conn, Statement stmnt, ResultSet rst) {
		closeResultSet(rst);
		closeStatement(stmnt);
		closeConnection(conn);
	}

	/**
	 * 데이터베이스 자원을 해제 한다.
	 * 
	 * @param conn
	 * @deprecated
	 */
	public static void cleanup(Connection conn) {
		closeConnection(conn);
	}

	/**
	 * 데이터베이스 자원을 해제 한다.
	 * 
	 * @param stmnt
	 * @deprecated
	 */
	public static void cleanup(Statement stmnt) {
		closeStatement(stmnt);
	}

	/**
	 * 데이터베이스 자원을 해제 한다.
	 * 
	 * @param rst
	 * @deprecated
	 */
	public static void cleanup(ResultSet rst) {
		closeResultSet(rst);
	}

	/**
	 * 커넥션을 종료합니다.
	 * 
	 * @param conn
	 */
	public static void closeConnection(Connection conn) {
		try {
			if (conn != null) {
				if (!conn.isClosed()) {
					conn.close();
				}
			}
		} catch (SQLException sqle) {
			log.error(sqle);
			throw new ConnectionException("Close connection faild : " + sqle.getMessage());

		}

	}

	/**
	 * 스테이트먼트를 종료합니다.
	 * 
	 * @param stmnt
	 */
	public static void closeStatement(Statement stmnt) {

		try {
			if (stmnt != null) {
				stmnt.close();
			}
		} catch (SQLException sqle) {
			log.error(sqle);
			throw new ConnectionException("Close statement faild : " + sqle.getMessage());
			// swallow exception. Since we're closing it we'll let it be
			// dead.
		}

	}

	/**
	 * 리절트 셋을 종료합니다.
	 * 
	 * @param rst
	 */
	public static void closeResultSet(ResultSet rst) {

		try {
			if (rst != null) {
				rst.close();
			}
		} catch (SQLException sqle) {
			log.error(sqle);
			throw new ConnectionException("Close resultset failed : " + sqle.getMessage());

		}

	}

	/**
	 * 커넥션을 커밋합니다.
	 * 
	 * @param conn
	 */
	public static void commitConnection(Connection conn) {

		try {
			if (conn != null) {
				conn.commit();
				// setAutoCommit(conn, true);//
			}
		} catch (SQLException sqle) {
			log.error(sqle);
			throw new ConnectionException("Connection commit failed : " + sqle.getMessage());
		}
	}

	/**
	 * 커넥션을 롤백합니다.
	 * 
	 * @param conn
	 */
	public static void rollbackConnection(Connection conn) {

		try {
			if (conn != null) {
				conn.rollback();
			}
		} catch (SQLException sqle) {
			log.error(sqle);
			throw new ConnectionException("Connection rollback failed : " + sqle.getMessage());
		}
	}

	/**
	 * 커넥션의 AutoCommit을 설정한다.
	 * 
	 * @param conn
	 * @param isAutoCommit
	 */
	public static void setAutoCommit(Connection conn, boolean isAutoCommit) {
		try {
			if (conn != null) {
				if (conn.getAutoCommit() != isAutoCommit) {
					conn.setAutoCommit(isAutoCommit);
				}
			}
		} catch (SQLException sqle) {
			log.error(sqle);
			throw new ConnectionException("Setting auto commit failed : " + sqle.getMessage());
		}
	}

	public static boolean isAutoCommit(Connection conn) {
		try {
			return conn.getAutoCommit();
		} catch (SQLException sqle) {
			log.error(sqle);
			throw new ConnectionException("Getting isAutoCommit failed : " + sqle.getMessage());
		}
	}

}
