/*
 *  JDesigner (R) Web Application Development Platform 
 *  Copyright (C) 2010 JDesigner / SangBoo Lee (leesangboo@gmail.com)
 * 
 *  http://www.jdesigner.org/
 *  
 *  Please contact if you require licensing terms other
 *  than GPL-3 for this software.
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.jdesigner.platform.db.handler;

import java.lang.reflect.Method;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.Properties;

import org.apache.commons.lang.StringUtils;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import org.jdesigner.platform.util.ReflectionUtils;

/**
 * PropertiesColumnTypeResultObjectHandler
 * 
 * @author leesangboo
 * 
 */
public class PropertiesColumnTypeResultObjectHandler implements ColumnTypeResultObjectHandler {

	private static final Log log = LogFactory.getLog(PropertiesColumnTypeResultObjectHandler.class);

	/*
	 * @see org.jdesigner.platform.db.handler.ColumnTypeResultObjectHandler#getObject (java.sql.ResultSet, java.lang.String)
	 */
	public Object getObject(ResultSet rs, String columnType, String columnName, int columnIndex) throws SQLException {

		try {

			PropertiesFactory propertiesFactory = PropertiesFactory.getInstance();
			Properties properties = propertiesFactory.getProperties();

			log.debug("Find mached cloumn type and rs method : " + columnType + "=" + properties.getProperty(columnType));

			if (StringUtils.isNotEmpty(properties.getProperty(columnType))) {
				String methodName = properties.getProperty(columnType);
				Method method = rs.getClass().getMethod(methodName, new Class[] { java.lang.Integer.TYPE });
				Object value = ReflectionUtils.invokeMethod(method, rs, new Object[] { new Integer(columnIndex) });
				log.debug("Reflection rs mapping method invoked : " + method);
				return value;
			} else {
				log.debug("Default getObject method invoked.");
				return rs.getObject(columnIndex);
			}
		} catch (Exception ex) {
			throw new SQLException("PropertiesColumnTypeResultObjectHandler Error : " + ex.getMessage());
		}
	}

}
