/*
 *  JDesigner (R) Web Application Development Platform 
 *  Copyright (C) 2010 JDesigner / SangBoo Lee (leesangboo@gmail.com)
 * 
 *  http://www.jdesigner.org/
 *  
 *  Please contact if you require licensing terms other
 *  than GPL-3 for this software.
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.jdesigner.platform.db.paging;

import org.jdesigner.platform.context.ApplicationConfig;
import org.jdesigner.platform.context.ApplicationContextFactory;
import org.jdesigner.platform.db.parser.QueryParsingException;
import org.jdesigner.platform.db.vender.DatabaseName;

/**
 * PagingSQLHandlerFactory
 * 
 * @author leesangboo
 * 
 */
public class PagingSQLHandlerFactory {

	private static final String DATABASE_NAME_KEY = "platform.db.database";

	private static class PagingSQLHandlerFactoryHolder {
		static PagingSQLHandlerFactory instance = new PagingSQLHandlerFactory();
	}

	public static PagingSQLHandlerFactory getInstance() {
		return PagingSQLHandlerFactoryHolder.instance;
	}

	private PagingSQLHandler pagingSQLHandler;

	/**
	 * PagingSQL
	 * 
	 * @return
	 * @throws QueryParsingException
	 */
	public PagingSQLHandler getPagingSQLHandler() throws QueryParsingException {
		if (pagingSQLHandler == null) {
			ApplicationContextFactory appFactory = ApplicationContextFactory.getInstance();
			ApplicationConfig appConfig = appFactory.getApplicationContext().getApplicationConfig();
			String dbName = appConfig.getProperty(DATABASE_NAME_KEY);
			//
			if (dbName.startsWith(DatabaseName.ORACLE)) {
				pagingSQLHandler = new OraclePagingSQLHandler();
			} else {
				throw new QueryParsingException("Unsupport paging this database type : " + dbName);
			}
			return pagingSQLHandler;
		} else {
			return pagingSQLHandler;
		}

	}

}
