/*
 *  JDesigner (R) Web Application Development Platform 
 *  Copyright (C) 2010 JDesigner / SangBoo Lee (leesangboo@gmail.com)
 * 
 *  http://www.jdesigner.org/
 *  
 *  Please contact if you require licensing terms other
 *  than GPL-3 for this software.
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.jdesigner.platform.db.parser;

import org.jdesigner.platform.db.query.NamedQuery;
import org.jdesigner.platform.db.query.Query;
import org.jdesigner.platform.db.query.TableQuery;

/**
 * SQLParserFactory
 * 
 * @author leesangboo
 * 
 */
public class SQLParserFactory {

	/**
	 * SQLParser를 반환한다.
	 * 
	 * @param query
	 * @return
	 */
	public static SQLParser getQueryParser(Object query) {
		if (query instanceof Query) {
			return new QuerySQLParser();
		} else if (query instanceof NamedQuery) {
			return new NamedQuerySQLParser();
		} else if (query instanceof TableQuery) {
			return new TableQuerySQLParser();
		} else {
			throw new QueryParsingException("Unsupport Query class type : type=[" + query.getClass() + "]");
		}
	}

}
