/*
 *  JDesigner (R) Web Application Development Platform 
 *  Copyright (C) 2010 JDesigner / SangBoo Lee (leesangboo@gmail.com)
 * 
 *  http://www.jdesigner.org/
 *  
 *  Please contact if you require licensing terms other
 *  than GPL-3 for this software.
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.jdesigner.platform.db.processor;

import java.sql.SQLException;
import java.util.List;
import java.util.Map;

import org.jdesigner.platform.exception.DatabaseException;

/**
 * QueryProcessingException
 * @author leesangboo
 *
 */
public class QueryProcessingException extends DatabaseException {

	private static final long serialVersionUID = 6562891095136246144L;

	private String errorCode;
	private String sql;

	private List listParameters;
	private Map mapParameters;

	public QueryProcessingException(String msg) {
		super(msg);
	}

	public QueryProcessingException(String msg, Throwable ex) {
		super(msg, ex);
		if (ex instanceof SQLException) {
			this.errorCode = "SQLE-" + ((SQLException) ex).getErrorCode() + "-" + ((SQLException) ex).getSQLState();
		}
	}

	public QueryProcessingException(String errorCode, String sql, List listParameters, String msg, Throwable ex) {
		super(msg, ex);
		this.errorCode = errorCode;
		this.sql = sql;
		this.listParameters = listParameters;
	}

	public String getErrorCode() {
		return errorCode;
	}

	public void setErrorCode(String errorCode) {
		this.errorCode = errorCode;
	}

	public List getListParameters() {
		return listParameters;
	}

	public void setListParameters(List listParameters) {
		this.listParameters = listParameters;
	}

	public Map getMapParameters() {
		return mapParameters;
	}

	public void setMapParameters(Map mapParameters) {
		this.mapParameters = mapParameters;
	}

	public String getSql() {
		return sql;
	}

	public void setSql(String sql) {
		this.sql = sql;
	}

	/*
	 * public String toString() { StringBuffer buffer = new StringBuffer(); buffer.append("QueryProcessingException : ");
	 * buffer.append("errorCode = ").append(errorCode).append(", "); if (sql != null) buffer.append("sql = ").append(sql).append(", ");; if
	 * (listParameters != null) buffer.append("listParameters = ").append(listParameters).append(", ");; if (mapParameters != null)
	 * buffer.append("mapParameters = ").append(mapParameters).append(", ");; return toString(); }
	 */

}