/*
 *  JDesigner (R) Web Application Development Platform 
 *  Copyright (C) 2010 JDesigner / SangBoo Lee (leesangboo@gmail.com)
 * 
 *  http://www.jdesigner.org/
 *  
 *  Please contact if you require licensing terms other
 *  than GPL-3 for this software.
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.jdesigner.platform.db.provider.rdbms;

import org.apache.commons.dbutils.ResultSetHandler;

import org.jdesigner.platform.db.lob.LOBHandler;
import org.jdesigner.platform.db.paging.PagingSQLHandler;
import org.jdesigner.platform.db.parameter.ParameterBinder;
import org.jdesigner.platform.db.provider.RDBMSProvider;
import org.jdesigner.platform.db.provider.rdbms.oracle.OracleColumnTypeResultObjectHandler;
import org.jdesigner.platform.db.provider.rdbms.oracle.OracleDataMapListResultSetHandler;
import org.jdesigner.platform.db.provider.rdbms.oracle.OracleDataMapResultSetHandler;
import org.jdesigner.platform.db.provider.rdbms.oracle.OracleDataObjectResultSetHandler;
import org.jdesigner.platform.db.provider.rdbms.oracle.OracleLOBHandler;
import org.jdesigner.platform.db.provider.rdbms.oracle.OraclePagingSQLHandler;
import org.jdesigner.platform.db.provider.rdbms.oracle.OracleParameterBinder;
import org.jdesigner.platform.db.provider.rdbms.oracle.OracleSequenceHandler;
import org.jdesigner.platform.db.provider.rdbms.oracle.OracleTableTypeMaker;
import org.jdesigner.platform.db.result.ColumnTypeResultObjectHandler;
import org.jdesigner.platform.db.sequence.SequenceHandler;
import org.jdesigner.platform.db.table.rdbms.TableTypeMaker;
import org.jdesigner.platform.exception.DatabaseException;

/**
 * OracleRDBMSProvider
 * 
 * @author leesangboo
 * 
 */
public class OracleRDBMSProvider implements RDBMSProvider {

	/*
	 * (non-Javadoc)
	 * 
	 * @see org.jdesigner.platform.db.provider.RDBMSProvider#getLOBHandler()
	 */
	public LOBHandler getLOBHandler() throws DatabaseException {
		return new OracleLOBHandler();
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see org.jdesigner.platform.db.provider.RDBMSProvider#getParameterBinder()
	 */
	public ParameterBinder getParameterBinder() throws DatabaseException {
		return new OracleParameterBinder();
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see org.jdesigner.platform.db.provider.RDBMSProvider#getColumnTypeResultObjectHandler()
	 */
	public ColumnTypeResultObjectHandler getColumnTypeResultObjectHandler() throws DatabaseException {
		return new OracleColumnTypeResultObjectHandler();
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see org.jdesigner.platform.db.provider.RDBMSProvider#getSequenceHandler()
	 */
	public SequenceHandler getSequenceHandler() throws DatabaseException {
		return new OracleSequenceHandler();
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see org.jdesigner.platform.db.provider.RDBMSProvider#getTableTypeMaker()
	 */
	public TableTypeMaker getTableTypeMaker() throws DatabaseException {
		return new OracleTableTypeMaker();
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see org.jdesigner.platform.db.provider.RDBMSProvider#getPagingSQLHandler()
	 */
	public PagingSQLHandler getPagingSQLHandler() throws DatabaseException {
		return new OraclePagingSQLHandler();
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see org.jdesigner.platform.db.provider.RDBMSProvider#getMapListResultHandler()
	 */
	public ResultSetHandler getMapListResultHandler() throws DatabaseException {
		return new OracleDataMapListResultSetHandler();
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see org.jdesigner.platform.db.provider.RDBMSProvider#getMapResultHandler()
	 */
	public ResultSetHandler getMapResultHandler() throws DatabaseException {
		return new OracleDataMapResultSetHandler();
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see org.jdesigner.platform.db.provider.RDBMSProvider#getObjectResultHandler()
	 */
	public ResultSetHandler getObjectResultHandler() throws DatabaseException {
		return new OracleDataObjectResultSetHandler();
	}

}
