/*
 *  JDesigner (R) Web Application Development Platform 
 *  Copyright (C) 2010 JDesigner / SangBoo Lee (leesangboo@gmail.com)
 * 
 *  http://www.jdesigner.org/
 *  
 *  Please contact if you require licensing terms other
 *  than GPL-3 for this software.
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.jdesigner.platform.db.query.impl;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;

import org.jdesigner.platform.db.processor.QueryProcessor;
import org.jdesigner.platform.db.processor.impl.QueryProcessorImpl;
import org.jdesigner.platform.db.query.Query;
import org.jdesigner.platform.db.session.Session;

/**
 * <B>Query</B>
 * 
 * @author leesangboo
 * 
 */
public class QueryImpl extends SessionQuery implements Query {

	/**
	 * SQL 파일의 경로
	 */
	private String path; //

	/**
	 * 쿼리 파라메터
	 */
	private List parameters; //

	/**
	 * SQL 내의 변환 될 문자열 맵
	 */
	private Map converter; //

	/**
	 * Query 생성자
	 */
	public QueryImpl() {
		//
	}

	/**
	 * Query 생성자 (SQL)
	 * 
	 * @param path
	 *            - SQL XML 파일의 경로
	 */
	public QueryImpl(Session session, String path) {
		super.setSession(session);
		this.path = path;
	}

	/**
	 * Query 생성자 (SQL)
	 * 
	 * @param path
	 *            - SQL XML 파일의 경로
	 * @param parameters
	 *            - 쿼리 파라메터
	 */
	public QueryImpl(Session session, String path, List parameters) {
		super.setSession(session);
		this.path = path;
		this.parameters = parameters;
	}

	/**
	 * Query 생성자 (SQL)
	 * 
	 * @param path
	 *            - SQL XML 파일의 경로
	 * @param parameters
	 *            - 쿼리 파라메터
	 * @param converter
	 *            - SQL 내의 변환될 문자열 맵
	 */
	public QueryImpl(Session session, String path, List parameters, Map converter) {
		super.setSession(session);
		this.path = path;
		this.parameters = parameters;
		this.converter = converter;
	}

	/**
	 * Query 실행을 위한 프로세서를 반환한다.
	 * 
	 * @return
	 */
	public QueryProcessor execute() {
		return new QueryProcessorImpl(this);
	}

	public String getPath() {
		return path;
	}

	public void setPath(String path) {
		this.path = path;
	}

	public List getParameters() {
		return parameters;
	}

	public void setParameters(List parameters) {
		this.parameters = parameters;
	}

	public Map getConverter() {
		return converter;
	}

	public void setConverter(Map converter) {
		this.converter = converter;
	}

	public void addParameter(Object value) {
		if (parameters == null) {
			parameters = new ArrayList();
		}
		parameters.add(value);
	}

}
