/*
 *  JDesigner (R) Web Application Development Platform 
 *  Copyright (C) 2010 JDesigner / SangBoo Lee (leesangboo@gmail.com)
 * 
 *  http://www.jdesigner.org/
 *  
 *  Please contact if you require licensing terms other
 *  than GPL-3 for this software.
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.jdesigner.platform.db.session;

import java.sql.Connection;

import org.jdesigner.platform.db.transaction.Transaction;
import org.jdesigner.platform.db.transaction.TransactionFactory;
import org.jdesigner.platform.db.transaction.TransactionManager;

/**
 * Session
 * 
 * @author leesangboo
 * 
 */
public class Session {

	private String id;

	private String dataSourceJNDIName;

	private int transactionType = Integer.MIN_VALUE;

	private Transaction transaction;

	private TransactionFactory trasactionFactory = new TransactionFactory();

	private TransactionManager transactionManager = new TransactionManager();

	public Session(String id, String dataSourceJNDIName, int transactionType) {
		this.id = id;
		this.dataSourceJNDIName = dataSourceJNDIName;
		this.transactionType = transactionType;
		this.createTransaction();
	}

	public void createTransaction() {
		this.transaction = trasactionFactory.createTransaction(transactionType, dataSourceJNDIName);
	}

	public void removeTransaction() {
		this.transaction = null;
	}

	public Connection getConnection() {
		return getTransaction().getConnection();
	}

	public void changeConnection(String dataSourceJNDIName) {
		this.dataSourceJNDIName = dataSourceJNDIName;
		getTransaction().changeConnection(dataSourceJNDIName);
	}

	public String getDataSourceJNDIName() {
		return dataSourceJNDIName;
	}

	public int getTransactionType() {
		return transactionType;
	}

	public Transaction getTransaction() {
		if (transaction == null) {
			createTransaction();
		}
		return transaction;
	}

	public void startTransaction() {
		transactionManager.start(transaction);
	}

	public void commitTransaction() {
		transactionManager.commit(transaction);
	}

	public void endTransaction() {
		transactionManager.end(transaction);
	}

	public String getId() {
		return id;
	}

}
