/*
 *  JDesigner (R) Web Application Development Platform 
 *  Copyright (C) 2010 JDesigner / SangBoo Lee (leesangboo@gmail.com)
 * 
 *  http://www.jdesigner.org/
 *  
 *  Please contact if you require licensing terms other
 *  than GPL-3 for this software.
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.jdesigner.platform.db.table;

import java.sql.DatabaseMetaData;

import org.jdesigner.platform.db.processor.TableQueryProcessor;
import org.jdesigner.platform.db.query.TableQuery;
import org.jdesigner.platform.db.table.model.TableLayout;
import org.jdesigner.platform.db.table.sql.SQLGenerator;
import org.jdesigner.platform.db.table.sql.SQLGeneratorFactory;
import org.jdesigner.platform.util.MapUtils;

/**
 * TableSQLLoader
 * 
 * @author leesangboo
 * 
 */
public class TableSQLLoader {

	/**
	 * 
	 * @param query
	 * @param mode
	 * @return
	 * @throws TableSQLException
	 */
	public String loadSQLFromTableQueryAndMode(TableQuery query, String mode) throws TableSQLException {
		// ConnectionManager manager = new ConnectionManager();
		// Connection conn = null;
		try {

			//
			// conn = manager.getConnection();
			// ((OracleConnection)conn).setRemarksReporting(true);
			// conn = query.getConnection();

			//
			DatabaseMetaData dm = query.getSession().getConnection().getMetaData();
			TableLayoutLoader tableLayoutLoader = new TableLayoutLoader();
			TableLayout tableLayout = tableLayoutLoader.getTableLayout(query.getSession().getConnection(), dm, query.getTableName(), query.getPrimaryKeys());

			// INSERT or UPDATE Only Param Key Binding Check
			if ((mode.equals(TableQueryProcessor.INSERT) || mode.equals(TableQueryProcessor.UPDATE)) && query.getProcessTargetColumns() == null && query.isOnlyParamKeyBinding()) {
				query.setOnlyParamKeyBinding(true);
				query.setProcessTargetColumns(MapUtils.getKeyArray(query.getParameters()));
			}

			//
			SQLGenerator generatedSQL = SQLGeneratorFactory.getSQLGenerator(mode);
			return generatedSQL.generateSQL(tableLayout, query.getProcessTargetColumns());

		} catch (Exception ex) {
			throw new TableSQLException("Failed load SQL from table infomation.", ex);
		} finally {
			// ConnectionUtils.closeConnection(conn);
		}
	}

}
