/*
 *  JDesigner (R) Web Application Development Platform 
 *  Copyright (C) 2010 JDesigner / SangBoo Lee (leesangboo@gmail.com)
 * 
 *  http://www.jdesigner.org/
 *  
 *  Please contact if you require licensing terms other
 *  than GPL-3 for this software.
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.jdesigner.platform.jndi;

import java.util.HashMap;
import java.util.Map;

import javax.naming.Context;
import javax.naming.NamingException;
import javax.transaction.UserTransaction;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

/**
 * JTA 서비스 로케이터
 * 
 * @author Administrator
 * 
 */
public class JTAServiceLocator {

	private static final Log log = LogFactory.getLog(JTAServiceLocator.class);

	private static class JTAServiceLocatorHolder {
		static JTAServiceLocator instance = new JTAServiceLocator();
	}

	public static JTAServiceLocator getInstance() {
		return JTAServiceLocatorHolder.instance;
	}

	/**
	 * 유저 트랜잭션을 반환한다.
	 * 
	 * @param jndiName
	 * @return
	 * @throws Exception
	 */
	public UserTransaction getUserTransaction(String jndiName) throws Exception {
		Context context = null;
		UserTransaction utx = null;
		try {
			if (cache.containsKey(jndiName)) {
				utx = (UserTransaction) cache.get(jndiName);
			} else {

				ContextFactory contextFactory = ContextFactory.getInstance();
				context = contextFactory.getContext();

				utx = (UserTransaction) context.lookup(jndiName);
				cache.put(jndiName, utx);
			}

		} catch (NamingException nex) {
			String msg = "Cannot get UserTransaction instance , invaild JNDI name [" + jndiName + "] : " + nex.getMessage();
			log.error(msg, nex);
			throw new ServiceLocatorException(msg, nex);
		} catch (Exception ex) {
			String msg = "Cannot get UserTransaction instance : " + ex.getMessage();
			log.error(msg, ex);
			throw new ServiceLocatorException(ex);
		}
		return utx;
	}

	private Map cache = new HashMap();

}
