/*
 *  JDesigner (R) Web Application Development Platform 
 *  Copyright (C) 2010 JDesigner / SangBoo Lee (leesangboo@gmail.com)
 * 
 *  http://www.jdesigner.org/
 *  
 *  Please contact if you require licensing terms other
 *  than GPL-3 for this software.
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.jdesigner.platform.web;

import java.util.Locale;

import javax.servlet.ServletContext;
import javax.servlet.http.HttpServletRequest;

import org.apache.struts.Globals;
import org.apache.struts.action.ActionErrors;
import org.apache.struts.action.ActionMessage;
import org.apache.struts.config.ModuleConfig;
import org.apache.struts.util.MessageResources;
import org.apache.struts.util.ModuleUtils;
import org.apache.struts.util.RequestUtils;

import org.jdesigner.platform.web.multipart.MultipartException;

/**
 * ActionEvent
 * 
 * @author leesangboo
 * 
 */
public class ActionEvent implements WebConstants {

	private HttpServletRequest request;

	public ActionEvent(HttpServletRequest request) {
		this.request = request;
	}

	/**
	 * 멀티파트 파일업로드 도중 오류 발생 여부를 반환한다.
	 * 
	 * @return
	 */
	public boolean hasMultipartError() {
		return this.getMultipartException() != null ? true : false;
	}

	/**
	 * 멀티파트 파일업로드 예외 메세지 를 반환한다.
	 * 
	 * @return
	 */
	public ActionMessage getMultipartErrorMessage() {
		return (ActionMessage) request.getAttribute(MULTIPART_ERROR_MESSAGE_KEY);
	}

	/**
	 * 멀티파트 파일업로드 예외를 반환한다.
	 * 
	 * @return
	 */
	public MultipartException getMultipartException() {
		MultipartException exception = ((MultipartException) request.getAttribute(MULTIPART_ERROR_KEY));
		return exception;
	}

	/**
	 * 사용자가 설정한 검증자의 검증실행 도중 오류 발생 여부를 반환한다.
	 * 
	 * @return
	 */
	public boolean hasValidateError() {
		return getValidateErrorMessages() != null ? true : false;
	}

	/**
	 * 사용자가 설정한 검증자의 검증실행 도중 오류 메세지(s)를 반환한다.
	 * 
	 * @return
	 */
	public ActionErrors getValidateErrorMessages() {
		return (ActionErrors) request.getAttribute(VALIDATION_ERROR_MESSAGES_KEY);
	}

	/**
	 * 기본 메세지 자원을 반환한다.
	 */
	public MessageResources getMessageResources() {
		return ((MessageResources) request.getAttribute(Globals.MESSAGES_KEY));
	}

	/**
	 * 메세지 자원을 반환한다.
	 * 
	 * @param key
	 * @return
	 */
	public MessageResources getMessageResources(String key) {
		ServletContext context = request.getSession().getServletContext();
		ModuleConfig moduleConfig = ModuleUtils.getInstance().getModuleConfig(request, context);
		return (MessageResources) context.getAttribute(key + moduleConfig.getPrefix());
	}

	/**
	 * 사용자의 현재 Locale을 반환한다.
	 * 
	 * @return
	 */
	public Locale getLocale() {
		return RequestUtils.getUserLocale(request, null);
	}

	/**
	 * 폼에서 취소 버튼을 눌렀는지의 여부를 반환한다.
	 * 
	 * @return
	 */
	public boolean isCancelled() {
		return (request.getAttribute(Globals.CANCEL_KEY) != null);
	}

	/**
	 * 토큰의 검증 여부를 반환한다.
	 * 
	 * @return
	 */
	public boolean isTokenValid() {
		return (request.getAttribute(WebConstants.TOKEN_ERROR_MESSAGE_KEY) != null);
	}

}
