/*
 *  JDesigner (R) Web Application Development Platform 
 *  Copyright (C) 2010 JDesigner / SangBoo Lee (leesangboo@gmail.com)
 * 
 *  http://www.jdesigner.org/
 *  
 *  Please contact if you require licensing terms other
 *  than GPL-3 for this software.
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.jdesigner.platform.web;

import java.lang.reflect.Method;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.apache.commons.lang.StringUtils;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.apache.struts.action.Action;
import org.apache.struts.action.ActionErrors;
import org.apache.struts.action.ActionForm;
import org.apache.struts.action.ActionForward;
import org.apache.struts.action.ActionMapping;
import org.apache.struts.action.ActionMessage;
import org.apache.struts.action.ActionMessages;

import org.jdesigner.platform.web.multipart.MultipartException;
import org.jdesigner.platform.web.multipart.MultipartExceptionHandler;
import org.jdesigner.platform.web.multipart.MultipartExceptionHandlerImpl;

/**
 * 
 * <B>Bean Action</B>
 * 
 * @author leesangboo
 * 
 */
public class BeanAction extends Action {

	private static final Log log = LogFactory.getLog(BeanAction.class);

	private static final String NO_METHOD_CALL = "*";

	/*
	 * @seeorg.apache.struts.action.Action#execute(org.apache.struts.action. ActionMapping, org.apache.struts.action.ActionForm,
	 * javax.servlet.http.HttpServletRequest, javax.servlet.http.HttpServletResponse)
	 */
	public final ActionForward execute(ActionMapping mapping, ActionForm form, HttpServletRequest request, HttpServletResponse response) throws Exception {

		String forward = null;

		try {

			// Form Bean Check
			if (!(form instanceof BaseBean)) {
				if (form != null) {
					throw new BeanActionException("The form for mapping '" + mapping.getPath() + "' named '" + mapping.getName()
							+ "' was not an instance of BaseBean.  BeanAction requires an BaseBean instance.");
				} else {
					throw new BeanActionException("The form for mapping '" + mapping.getPath() + "' named '" + mapping.getName() + "' was null.  BeanAction requires an BaseBean instance.");
				}
			}

			// Multipart Error Handle
			if (request.getAttribute(WebConstants.MULTIPART_ERROR_KEY) != null) {
				MultipartException exception = (MultipartException) request.getAttribute(WebConstants.MULTIPART_ERROR_KEY);
				MultipartExceptionHandler handler = new MultipartExceptionHandlerImpl();
				ActionMessage message = handler.handleException(exception);
				if (StringUtils.isNotEmpty(mapping.getInput())) {
					ActionErrors errors = new ActionErrors();
					errors.add(WebConstants.MULTIPART_ERROR_KEY, message);
					super.saveErrors(request, errors);
					log.info("Multipart file upload failed, setting foward to [input] mapping : " + mapping.getInput());
					return new ActionForward(mapping.getInput());
				} else {
					request.setAttribute(WebConstants.MULTIPART_ERROR_MESSAGE_KEY, message);
					log.info("Multipart exception handling in your ActionBean.");
				}
			}

			// Token Validate
			boolean saveToken = false;
			if (mapping instanceof org.jdesigner.platform.web.ActionMapping) {
				org.jdesigner.platform.web.ActionMapping t_mapping = (org.jdesigner.platform.web.ActionMapping) mapping;
				saveToken = t_mapping.isTokenSave();
			}
			if (saveToken) {
				saveToken(request);
			}

			boolean validateToken = false;
			boolean resetToken = false;
			if (mapping instanceof org.jdesigner.platform.web.ActionMapping) {
				org.jdesigner.platform.web.ActionMapping t_mapping = (org.jdesigner.platform.web.ActionMapping) mapping;
				validateToken = t_mapping.isTokenValidate();
				resetToken = t_mapping.isTokenReset();
			}

			if (validateToken) {
				if (!isTokenValid(request, resetToken)) {
					ActionMessage message = new ActionMessage("web.error.duplicate.submit");
					if (StringUtils.isNotEmpty(mapping.getInput())) {
						ActionErrors errors = new ActionErrors();
						errors.add(WebConstants.TOKEN_ERROR_KEY, message);
						super.saveErrors(request, errors);
						log.info("Token failed, setting foward to [input] mapping : " + mapping.getInput());
						return new ActionForward(mapping.getInput());
					} else {
						request.setAttribute(WebConstants.TOKEN_ERROR_MESSAGE_KEY, message);
						log.info("Token exception handling in your ActionBean.");
					}
				}
			}

			// Validation Error Handle
			if (request.getAttribute(WebConstants.VALIDATION_ERROR_KEY) != null) {
				ActionErrors errors = (ActionErrors) request.getAttribute(WebConstants.VALIDATION_ERROR_KEY);
				if (StringUtils.isNotEmpty(mapping.getInput())) {
					super.saveErrors(request, errors);
					log.info("Validate failed, setting foward to [input] mapping : " + mapping.getInput());
					return new ActionForward(mapping.getInput());
				} else {
					request.setAttribute(WebConstants.VALIDATION_ERROR_MESSAGES_KEY, errors);
					log.info("Validate exception handling in your ActionBean.");
				}
			}

			//
			BaseBean bean = (BaseBean) form;

			//
			ActionBeanContext.initCurrentContext(request, response);

			if (bean != null) {

				// Form Object binding
				DataObjectBinder.bind(request, bean);

				// Explicit Method Mapping
				Method method = null;
				String methodName = mapping.getParameter();
				if (methodName != null && !NO_METHOD_CALL.equals(methodName)) {
					try {
						method = bean.getClass().getMethod(methodName, null);
					} catch (Exception ex) {
						throw new BeanActionException("Error dispatching bean action via URL pattern ('" + methodName + "').  Cause: " + ex, ex);
					}
					;

					try {
						synchronized (bean) {
							forward = bean.getInterceptor().intercept(new ActionInvoker(bean, method));
						}
					} catch (Exception e) {
						e.printStackTrace();
						if ((Exception) e.getCause() != null && (Exception) e.getCause().getCause() != null) {
							throw (Exception) e.getCause().getCause(); //
						} else {
							throw e;
						}
					}
					;

				}

				// Path Based Method Mapping
				if (method == null && !NO_METHOD_CALL.equals(methodName)) {
					methodName = mapping.getPath();
					if (methodName.length() > 1) {
						int slash = methodName.lastIndexOf("/") + 1;
						methodName = methodName.substring(slash);
						if (methodName.length() > 0) {

							try {
								method = bean.getClass().getMethod(methodName, null);
							} catch (Exception ex) {
								throw new BeanActionException("Error dispatching bean action via URL pattern ('" + methodName + "').  Cause: " + ex, ex);
							}
							;

							try {
								synchronized (bean) {
									forward = bean.getInterceptor().intercept(new ActionInvoker(bean, method));
								}
							} catch (Exception e) {
								e.printStackTrace();
								if ((Exception) e.getCause() != null && (Exception) e.getCause().getCause() != null) {
									throw (Exception) e.getCause().getCause(); //
								} else {
									throw e;
								}
							}
						}
					}
				}
			}

			// Action Messages
			ActionMessages actionMessages = ActionBeanContext.getActionBeanContext().getActionMessages();
			if (!actionMessages.isEmpty()) {
				log.debug("Struts Action Messages Found : " + actionMessages.size());
				saveMessages(request, actionMessages);
			}

			// Action Errors
			ActionErrors actionErrors = ActionBeanContext.getActionBeanContext().getActionErrors();
			if (!actionErrors.isEmpty()) {
				log.debug("Struts Action Errors Found : " + actionErrors.size());
				saveErrors(request, actionErrors);
			}

		} catch (Exception e) {
			log.error("An error occurred while Struts BeanAction has run.");
			throw e;
		}

		return mapping.findForward(forward);

	}

}
