/*
 *  JDesigner (R) Web Application Development Platform 
 *  Copyright (C) 2010 JDesigner / SangBoo Lee (leesangboo@gmail.com)
 * 
 *  http://www.jdesigner.org/
 *  
 *  Please contact if you require licensing terms other
 *  than GPL-3 for this software.
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package org.jdesigner.platform.web.form;

import java.util.ArrayList;
import java.util.Collections;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import org.jdesigner.platform.web.Input;

/**
 * <B>Form</B>
 * 
 * @author leesangboo
 * 
 */
public class Form extends Input implements Map {

	private static final long serialVersionUID = 1L;

	private static final Log log = LogFactory.getLog(Form.class);

	/**
	 * 폼 모드
	 */
	public static final String MODE_KEY = "mode";
	public static final String ACTION_KEY = "action";

	/**
	 * 
	 */
	public Form() {
		super(new HashMap());
		this.setMode(FormMode.NONE);
	}

	/**
	 * 
	 * @param mode
	 */
	public Form(String mode) {
		super(new HashMap());
		this.setMode(mode);
	}

	/**
	 * 
	 * @param map
	 */
	public Form(Map map) {
		super(new HashMap());
		if (map != null) {
			this.putAll(map);
		}
		this.setMode(FormMode.NONE);
	}

	/**
	 * 폼 생성자
	 * 
	 * @param map
	 */
	public Form(Map map, String mode) {
		super(map);
		this.setMode(mode);
	}

	/**
	 * 폼 생성자
	 * 
	 * @param map
	 * @param mode
	 * @param url
	 */
	public Form(Map map, String mode, String url) {
		super(map);
		this.setMode(mode);
		this.setAction(url);
	}

	/**
	 * 폼 모드를 반환한다.
	 * 
	 * @return
	 */
	public String getMode() {
		return getString(MODE_KEY);
	}

	/**
	 * 폼 모드를 설정한다.
	 * 
	 * @param mode
	 */
	public void setMode(String mode) {
		this.put(MODE_KEY, mode);
	}

	/**
	 * 폼 액션를 반환한다.
	 * 
	 * @return
	 */
	public String getAction() {
		return getString(ACTION_KEY);
	}

	/**
	 * 폼 액션를 설정한다.
	 * 
	 * @param mode
	 */
	public void setAction(String url) {
		this.put(ACTION_KEY, url);
	}

	/**
	 * Form data print.
	 */
	public void print() {
		log.info("----------------------------------------------------");
		log.info(" FORM PRINT ");
		log.info("----------------------------------------------------");
		if (this != null && !this.isEmpty()) {
			List sortedKeys = new ArrayList(this.keySet());
			Collections.sort(sortedKeys);
			for (int i = 0; i < sortedKeys.size(); i++) {
				String key = (String) sortedKeys.get(i);
				if (this.containsKey(key)) {
					if (this.get(key).getClass().isArray() && ((Object[]) this.get(key)).length > 1) {
						int valueLength = ((Object[]) this.get(key)).length;
						Object[] values = ((Object[]) this.get(key));
						for (int x = 0; x < valueLength; x++) {
							log.info(" [" + key + "][" + x + "] -> " + values[x] + "");
						}
					} else {
						Object value = (this.get(key));
						log.info(" [" + key + "] -> " + value + "");
					}
				}
			}
		}
		log.info("----------------------------------------------------");
	}

	/**
	 * 
	 * @param key
	 * @param value
	 */
	public void put(String key, int value) {
		this.put(key, new Integer(value));
	}

	/**
	 * 
	 * @param key
	 * @param value
	 */
	public void put(String key, long value) {
		this.put(key, new Long(value));
	}

	/**
	 * 
	 * @param key
	 * @param value
	 */
	public void put(String key, float value) {
		this.put(key, new Float(value));
	}
}
