/*
 *  JDesigner (R) Web Application Development Platform 
 *  Copyright (C) 2010 JDesigner / SangBoo Lee (leesangboo@gmail.com)
 * 
 *  http://www.jdesigner.org/
 *  
 *  Please contact if you require licensing terms other
 *  than GPL-3 for this software.
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.jdesigner.platform.web.multipart;

import org.apache.commons.lang.exception.NestableRuntimeException;

/**
 * 멀티파트 예외
 * 
 * @author leesangboo
 * 
 */
public class MultipartException extends NestableRuntimeException {

	private static final long serialVersionUID = 1L;

	public static final int INITIALIZE_ERROR = 99;

	public static final int UN_CATCHED_ERROR = 0;

	public static final int MAX_FILE_SIZE_ERROR = 1;

	public static final int LIMIT_FILE_SUFFIX_ERROR = 2;

	private int errorCode = 0;

	private String parameter = null;

	private Throwable exceptionCause = null;

	public MultipartException(int errorCode, String parameter, String msg) {
		super(msg);
		this.errorCode = errorCode;
		this.parameter = parameter;
	}

	public MultipartException(int errorCode, String msg, Throwable exception) {
		super(msg, exception);
		this.errorCode = errorCode;
		this.exceptionCause = exception;
	}

	public MultipartException(int errorCode, String parameter, String msg, Throwable exception) {
		super(msg, exception);
		this.errorCode = errorCode;
		this.parameter = parameter;
		this.exceptionCause = exception;
	}

	public void printStackTrace() {
		if (this.exceptionCause != null) {
			System.err.println("Multipart Exception : " + this.exceptionCause.toString());
			this.exceptionCause.printStackTrace();
		}
	}

	public int getErrorCode() {
		return errorCode;
	}

	public String getParameter() {
		return parameter;
	}

	public void setParameter(String parameter) {
		this.parameter = parameter;
	}

}