/*
 *  JDesigner (R) Web Application Development Platform 
 *  Copyright (C) 2010 JDesigner / SangBoo Lee (leesangboo@gmail.com)
 * 
 *  http://www.jdesigner.org/
 *  
 *  Please contact if you require licensing terms other
 *  than GPL-3 for this software.
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.jdesigner.platform.web.tag.html;

import org.jdesigner.platform.web.tag.JSPTagException;

/**
 * CurrencyTag
 * 
 * @author leesangboo
 * 
 */
public class CurrencyTag extends ExtendedBaseFieldTag {

	private static final long serialVersionUID = 1L;

	public CurrencyTag() {
		super();
		this.type = "text";
		doReadonly = true;
	}

	private int precision = -1;

	private int scale = 0;

	private String decimalSeparator = ".";

	private String groupSeparator = ",";

	private String currencySymbol = "￦";

	private boolean useCurrency = true;

	private boolean negativeParenthesis = true;

	private boolean currencyInside = true;

	public String getDataType() {
		return "currency";
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see org.jdesigner.platform.web.tag.html.ExtendedBaseFieldTag#getSupportScript ()
	 */
	public String getSupportScript() {
		StringBuffer sb = null;
		try {
			sb = new StringBuffer();
			sb.append(SCRIPT_TAG_START);
			sb.append(" window.addEvent('domready', function(){ ");

			sb.append("		var _currency_parser_" + property.replaceAll("\\.", "_") + " = new NumberParser(" + scale + ", '" + decimalSeparator + "', '" + groupSeparator + "', true);  ");
			sb.append("		_currency_parser_" + property.replaceAll("\\.", "_") + ".currencySymbol = '" + currencySymbol + "';  ");
			sb.append(" 	_currency_parser_" + property.replaceAll("\\.", "_") + ".useCurrency = " + useCurrency + ";  ");
			sb.append(" 	_currency_parser_" + property.replaceAll("\\.", "_") + ".negativeParenthesis = " + negativeParenthesis + ";  ");
			// //sb.append(" 	_currency_parser_" + property +
			// ".currencyInside = " + currencyInside + ";  ");

			sb.append(" 	var _currency_mask_" + property.replaceAll("\\.", "_") + " = new NumberMask(_currency_parser_" + property.replaceAll("\\.", "_") + ", '" + property + "', " + precision
					+ ");  ");

			sb.append("    }); ");
			sb.append(SCRIPT_TAG_END);
			return sb.toString();
		} catch (Exception e) {
			throw new JSPTagException(e.getMessage(), e);
		}
	}

	public boolean isCurrencyInside() {
		return currencyInside;
	}

	public void setCurrencyInside(boolean currencyInside) {
		this.currencyInside = currencyInside;
	}

	public String getCurrencySymbol() {
		return currencySymbol;
	}

	public void setCurrencySymbol(String currencySymbol) {
		this.currencySymbol = currencySymbol;
	}

	public String getDecimalSeparator() {
		return decimalSeparator;
	}

	public void setDecimalSeparator(String decimalSeparator) {
		this.decimalSeparator = decimalSeparator;
	}

	public String getGroupSeparator() {
		return groupSeparator;
	}

	public void setGroupSeparator(String groupSeparator) {
		this.groupSeparator = groupSeparator;
	}

	public boolean isNegativeParenthesis() {
		return negativeParenthesis;
	}

	public void setNegativeParenthesis(boolean negativeParenthesis) {
		this.negativeParenthesis = negativeParenthesis;
	}

	public int getPrecision() {
		return precision;
	}

	public void setPrecision(int precision) {
		this.precision = precision;
	}

	public int getScale() {
		return scale;
	}

	public void setScale(int scale) {
		this.scale = scale;
	}

	public boolean isUseCurrency() {
		return useCurrency;
	}

	public void setUseCurrency(boolean useCurrency) {
		this.useCurrency = useCurrency;
	}

}
