/*
 *  JDesigner (R) Web Application Development Platform 
 *  Copyright (C) 2010 JDesigner / SangBoo Lee (leesangboo@gmail.com)
 * 
 *  http://www.jdesigner.org/
 *  
 *  Please contact if you require licensing terms other
 *  than GPL-3 for this software.
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package org.jdesigner.platform.web.tag.ui;

import java.io.Serializable;
import java.util.Locale;
import java.util.Map;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.servlet.jsp.JspException;
import javax.servlet.jsp.tagext.BodyTagSupport;
import javax.servlet.jsp.tagext.Tag;

import org.apache.struts.Globals;

import org.jdesigner.platform.web.WebUtils;
import org.jdesigner.platform.web.tag.ui.template.UITemplateModel;
import org.jdesigner.platform.web.tag.ui.template.UITemplateModelRenderer;
import org.jdesigner.platform.web.tag.ui.template.UITemplateModelRendererFactory;
import org.jdesigner.platform.web.theme.Theme;

/**
 * 
 * <B>Base Tag</B>
 * 
 * @author leesangboo
 * 
 */
abstract public class BaseUITag extends BodyTagSupport implements Tag, Serializable {

	private static final long serialVersionUID = 1L;

	protected Tag parent = null;

	protected String id;

	protected String title;

	protected String label;

	protected String bundle;

	protected boolean i18n;

	public BaseUITag() {
		init();
	}

	public void setParent(Tag t) {
		parent = t;
	}

	public Tag getParent() {
		return parent;
	}

	/**
	 * HttpServletRequest을 반환한다.
	 * 
	 * @return
	 */
	public HttpServletRequest getRequest() {
		return ((HttpServletRequest) pageContext.getRequest());
	}

	/***
	 * HttpServletResponse을 반환한다.
	 * 
	 * @return
	 */
	public HttpServletResponse getResponse() {
		return ((HttpServletResponse) pageContext.getResponse());
	}

	/**
	 * Context Path를 반환한다.
	 * 
	 * @return
	 */
	public String getContextPath() {
		return getRequest().getContextPath();
	}

	/**
	 * 사용자의 테마를 반환한다.
	 * 
	 * @return
	 */
	public Theme getUserTheme() {
		return WebUtils.getThemeHandler().getUserTheme(getRequest());
	}

	/**
	 * 사용자의 로케일을 반환한다.
	 * 
	 * @return
	 */
	public Locale getUserLocale() {
		return WebUtils.getLocaleHandler().getUserLocale(getRequest(), getResponse());
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see javax.servlet.jsp.tagext.Tag#doStartTag()
	 */
	public int doStartTag() throws JspException {
		try {

			this.setRenderingEnviroment();//

			UITemplateModel model = getStartModel();
			model.put("start", true);
			model.put("contextPath", getContextPath());
			model.put("themeImagesDirPath", getUserTheme().getImagesDirPath());
			UITemplateModelRendererFactory factory = UITemplateModelRendererFactory.getInstance();
			UITemplateModelRenderer render = factory.getJSPTemplateModelRenderer();
			render.render(pageContext, model);
		} catch (Exception e) {
			throw new UITagException("UI Tag Start Error : " + e.getMessage(), e);
		}
		return EVAL_BODY_INCLUDE;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see javax.servlet.jsp.tagext.Tag#doEndTag()
	 */
	public int doEndTag() throws JspException {
		try {
			this.setRenderingEnviroment();//

			String template = getEndModel().getTemplate();
			Map startMap = getStartModel().getRoot();
			Map endMap = getEndModel().getRoot();
			startMap.putAll(endMap);

			UITemplateModel model = new UITemplateModel(template, startMap);
			model.put("start", false);
			model.put("contextPath", getContextPath());
			model.put("themeImagesDirPath", getUserTheme().getImagesDirPath());
			UITemplateModelRendererFactory factory = UITemplateModelRendererFactory.getInstance();
			UITemplateModelRenderer render = factory.getJSPTemplateModelRenderer();
			render.render(pageContext, model);
		} catch (Exception e) {
			throw new UITagException("UI Tag End Error : " + e.getMessage(), e);
		}
		return EVAL_PAGE;
	}

	/*
	 * 
	 */
	public void init() {
		id = "";
		title = "";
		label = "";
		bundle = "";
		i18n = false;
		reset();
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see javax.servlet.jsp.tagext.Tag#release()
	 */
	public void release() {
		pageContext = null;
		parent = null;
		id = "";
		title = "";
		label = "";
		bundle = "";
		i18n = false;
		reset();
	}

	/**
	 * 시작 JSPTemplateModel을 반환한다.
	 * 
	 * @return
	 * @throws Exception
	 */
	public abstract UITemplateModel getStartModel() throws Exception;

	/**
	 * 완료 JSPTemplateModel을 반환한다.
	 * 
	 * @return
	 * @throws Exception
	 */
	public abstract UITemplateModel getEndModel() throws Exception;

	/**
	 * 파라메터를 리셋한다.
	 */
	public abstract void reset();

	/**
	 * 
	 */
	private void setRenderingEnviroment() {
		// struts xhtml setting
		pageContext.setAttribute(Globals.XHTML_KEY, "true");
	}

	public String getId() {
		return id;
	}

	public void setId(String id) {
		this.id = id;
	}

	public String getTitle() {
		return title;
	}

	public void setTitle(String title) {
		this.title = title;
	}

	public boolean isI18n() {
		return i18n;
	}

	public void setI18n(boolean i18n) {
		this.i18n = i18n;
	}

	public String getBundle() {
		return bundle;
	}

	public void setBundle(String bundle) {
		this.bundle = bundle;
	}

	public String getLabel() {
		return label;
	}

	public void setLabel(String label) {
		this.label = label;
	}

}
