/*
 *  JDesigner (R) Web Application Development Platform 
 *  Copyright (C) 2010 JDesigner / SangBoo Lee (leesangboo@gmail.com)
 * 
 *  http://www.jdesigner.org/
 *  
 *  Please contact if you require licensing terms other
 *  than GPL-3 for this software.
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.jdesigner.platform.web.tag.ui;

import java.util.Iterator;
import java.util.Map;
import java.util.Set;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.jsp.JspWriter;
import javax.servlet.jsp.tagext.TagSupport;

import org.jdesigner.platform.util.NumberUtils;
import org.jdesigner.platform.util.PatternMatchUtils;
import org.jdesigner.platform.util.StringUtils;

/**
 * Pagination Tag
 * 
 * @author leesangboo
 * 
 */
public class PaginationTag extends TagSupport {

	private static final long serialVersionUID = 1L;

	private String prefix;

	private String start;

	private String range;

	private String count;

	private String action;

	private String styleClass;

	private String title;

	public static final String SPACE = "";

	public static final String YES = "yes";

	public static final String START = ".start";

	public static final String RANGE = ".range";

	public static final String AND = "&";

	public static final String EQUALS = "=";

	public static final String ABEGIN = "<a href=\"";

	public static final String AEND = "</a>";

	public static final String QUESTION = "?";

	public static final String QUOT = "\"";

	public static final String BOLDSTART = "<b>";

	public static final String BOLDEND = "</b>";

	public static final String ITEMS = "Items";

	public static final String PAGES = "Pages";

	public static final String FIRST = "<< First";

	public static final String GT = "Next >";

	public static final String LT = "< Previous";

	public static final String PIPE = "|";

	public static final String LB = "";

	public static final String RB = "";

	public static final String[] SAVE_PATTERN = new String[] { "*insert.do*", "*update.do*", "*delete.do*", "*save.do*", "*execute.do*" };

	/**
	 * Returns the range.
	 * 
	 * @return String
	 */
	public String getRange() {
		return range;
	}

	/**
	 * Returns the start.
	 * 
	 * @return String
	 */
	public String getStart() {
		return start;
	}

	/**
	 * Sets the range.
	 * 
	 * @param range
	 *            The range to set
	 */
	public void setRange(String range) {
		this.range = range;
	}

	/**
	 * Sets the start.
	 * 
	 * @param start
	 *            The start to set
	 */
	public void setStart(String start) {
		this.start = start;
	}

	public int doStartTag() {

		int start, range, count, pages, i, ci;
		boolean firstPage, hasPreviousPage, hasNextPage;

		start = NumberUtils.toInt(this.start, 0);
		range = NumberUtils.toInt(this.range, 15);
		count = NumberUtils.toInt(this.count, 0);

		pages = (count / range);
		pages = count % range == 0 ? pages : pages + 1;

		try {

			JspWriter out = pageContext.getOut();

			StringBuffer sb = null;
			sb = new StringBuffer();

			sb.append("<div class='pager'>");
			sb.append("<table cellpadding='0' cellspacing=0' border='0'>");
			sb.append("<tr>");
			sb.append(LB);

			/*
			 * sb.append(count).append(SPACE).append(ITEMS); sb.append(" / "); sb.append(pages).append(SPACE).append(PAGES);
			 * sb.append(SPACE).append("|").append(SPACE);
			 */

			// Result 시작
			int dispCount = 0;
			if ((Integer.parseInt(this.start) + Integer.parseInt(this.range)) >= Integer.parseInt(this.count)) {
				dispCount = Integer.parseInt(this.count);
			} else {
				dispCount = (Integer.parseInt(this.start) + Integer.parseInt(this.range));
			}
			sb.append("<td>");
			sb.append("<div class='pagerSection'>");
			sb.append("<span class='pagerLabel'>Results:</span>").append(SPACE).append(this.start + " – " + dispCount + "  of  " + this.count);
			sb.append(SPACE).append(SPACE).append(SPACE);
			sb.append("</div>");
			sb.append("</td>");

			if (pages > 1) {

				ci = (start / range); // current index
				firstPage = ci < 2 ? true : false;
				hasPreviousPage = ci > 0 ? true : false;
				hasNextPage = ci < pages - 1 ? true : false;
				start = 0; // setting start to 0

				// 페이지 시작
				sb.append("<td>");
				sb.append("<div class='pagerSection'>");
				sb.append("<span class='pagerLabel'>Page:</span>").append(SPACE);

				if (!firstPage) {
					sb.append("<span class='pagerText'>");
					sb.append(getAnchor(0, range, FIRST)).append(SPACE);
					sb.append("</span>");
					sb.append("<span class='pagerText'>").append(PIPE).append("</span>");
				}

				if (hasPreviousPage) {
					sb.append("<span class='pagerText'>");
					sb.append(getAnchor((ci - 1) * range, range, LT)).append(SPACE);
					sb.append("</span>");
					sb.append("<span class='pagerText'>").append(PIPE).append("</span>");
				}

				/**
				 * logic for the anchors, we should show 5 achors both on the left and right of the current index if possible
				 */
				i = ci - 5 < 0 ? 0 : ci - 5;
				start = ci - 5 < 1 ? start : range * (ci - 5);
				pages = ci + 5 > pages ? pages : ci + 5;
				for (; i < pages; i++) {
					if (i == ci) {
						sb.append("<span class='pagerText'>");
						sb.append(BOLDSTART).append(i + 1).append(BOLDEND).append(SPACE);
						sb.append("</span>");
					} else {
						sb.append("<span class='pagerText'>");
						sb.append(getAnchor(start, range, i + 1));
						sb.append("</span>");
					}
					start += range;
				}
				if (hasNextPage) {
					sb.append("<span class='pagerText'>").append(PIPE).append("</span>");
					sb.append("<span class='pagerText'>");
					sb.append(SPACE).append(getAnchor((ci + 1) * range, range, GT));
					sb.append("</span>");
				}

				sb.append(RB);
				sb.append("</div>");
				sb.append("</td>");

			}

			//
			sb.append("<td>");
			sb.append(addChangeRangeCombo());
			sb.append("</td>");
			sb.append("</tr>");
			sb.append("</table>");
			sb.append("</div>");

			out.println(sb);

		} catch (Exception e) {
			e.printStackTrace();
		}

		return SKIP_BODY;
	}

	public int doEndTag() {
		return EVAL_PAGE;
	}

	private String getAnchor(int start, int range, int page) {
		return getAnchor(start, range, String.valueOf(page));
	}

	private String getAnchor(int start, int range, String page) {
		HttpServletRequest r = ((HttpServletRequest) pageContext.getRequest());
		String contextPath = r.getContextPath();
		String extension = "";

		String strutsUrl = (String) r.getAttribute("org.apache.struts.globals.ORIGINAL_URI_KEY");

		boolean hasQueryString = StringUtils.isEmpty(this.getQueryString(r.getParameterMap())) ? false : true;

		// 저장 이후 액션일 경우, 파라메터 초기화 //
		if (PatternMatchUtils.simpleMatch(SAVE_PATTERN, strutsUrl)) {
			hasQueryString = false;
		}

		StringBuffer url = new StringBuffer(r.getRequestURL().toString().substring(r.getRequestURL().toString().indexOf(r.getContextPath())));
		url = hasQueryString ? url.append(QUESTION).append(this.getQueryString(r.getParameterMap())).append(AND) : url.append(QUESTION);

		return addTitle(
				new StringBuffer(ABEGIN).append(
						this.action == null ? url : hasQueryString ? new StringBuffer(contextPath + this.action).append(extension).append(QUESTION).append(this.getQueryString(r.getParameterMap()))
								.append(AND) : new StringBuffer(contextPath + this.action).append(extension).append(QUESTION)).append(prefix + START).append(EQUALS).append(start).append(AND).append(
						prefix + RANGE).append(EQUALS).append(range).append(QUOT).append(GT).append(page).append(AEND).append(SPACE), page).toString();
	}

	/**
	 * Returns the results.
	 * 
	 * @return String
	 */
	public String getCount() {
		return count;
	}

	/**
	 * Sets the results.
	 * 
	 * @param results
	 *            The results to set
	 */
	public void setCount(String results) {
		this.count = results;
	}

	/**
	 * Returns the action.
	 * 
	 * @return String
	 */
	public String getAction() {
		return action;
	}

	/**
	 * Sets the action.
	 * 
	 * @param action
	 *            The action to set
	 */
	public void setAction(String action) {
		this.action = action;
	}

	/**
	 * 
	 * @param map
	 * @return
	 */
	public String getQueryString(Map map) {
		if (map == null) {
			return null;
		}
		StringBuffer sb = new StringBuffer();
		Set keys = map.keySet();
		Iterator iterator = keys.iterator();
		String obj = null;
		while (iterator.hasNext()) {
			obj = (String) iterator.next();
			if (!(prefix + START).equals(obj) && !(prefix + RANGE).equals(obj)) {
				sb.append(obj).append(EQUALS).append(((String[]) map.get(obj))[0]).append(AND);
			}
		}
		return sb.toString().endsWith(AND) ? sb.toString().substring(0, sb.toString().length() - 1) : sb.toString();
	}

	/**
	 * Returns the styleClass.
	 * 
	 * @return String
	 */
	public String getStyleClass() {
		return styleClass;
	}

	/**
	 * Sets the styleClass.
	 * 
	 * @param styleClass
	 *            The styleClass to set
	 */
	public void setStyleClass(String styleClass) {
		this.styleClass = styleClass;
	}

	/**
	 * Returns the title.
	 * 
	 * @return String
	 */
	public String getTitle() {
		return title;
	}

	/**
	 * Sets the title.
	 * 
	 * @param title
	 *            The title to set
	 */
	public void setTitle(String title) {
		this.title = title;
	}

	public String getPrefix() {
		return prefix;
	}

	public void setPrefix(String prefix) {
		this.prefix = prefix;
	}

	private StringBuffer addTitle(StringBuffer sb, String page) {
		if (sb == null || StringUtils.isEmpty(page)) {
			return sb;
		}
		if (StringUtils.isNotEmpty(this.title) && StringUtils.trim(this.title).equals(YES)) {
			StringBuffer tt = new StringBuffer("<span title=\"");
			if (page.equals(LT)) {
				tt.append("Previous page\">");
			} else if (page.equals(GT)) {
				tt.append("Next page\">");
			} else if (page.equals(FIRST)) {
				tt.append("First page\">");
			} else {
				tt.append("Go to page " + page + "\">");
			}
			tt.append(sb);
			tt.append("</span>");
			return tt;
		}
		return sb;
	}

	private String addChangeRangeCombo() {

		HttpServletRequest request = ((HttpServletRequest) pageContext.getRequest());

		StringBuffer buffer = new StringBuffer();

		// buffer.append(SPACE).append(SPACE).append(SPACE);
		buffer.append("<div class='pagerSection'>");
		buffer.append("<table cellpadding='0' cellspacing='0' border='0'>");
		buffer.append("<tr>");
		buffer.append("<td>");
		buffer.append("<span class='pagerLabel'>View:</span>").append(SPACE);
		buffer.append("</td>");
		buffer.append("<td>");
		buffer.append("<select id='' name='' onchange=\"location.href = '" + request.getContextPath() + action + "?" + prefix + RANGE + "=' + this.value\">");
		buffer.append("<option value='5'" + ((range.equals("5")) ? "selected" : "") + ">5</option>");
		buffer.append("<option value='10'" + ((range.equals("10")) ? "selected" : "") + ">10</option>");
		buffer.append("<option value='15'" + ((range.equals("15")) ? "selected" : "") + ">15</option>");
		buffer.append("<option value='20'" + ((range.equals("20")) ? "selected" : "") + ">20</option>");
		buffer.append("<option value='30'" + ((range.equals("30")) ? "selected" : "") + ">30</option>");
		buffer.append("<option value='50'" + ((range.equals("50")) ? "selected" : "") + ">50</option>");
		buffer.append("<option value='100'" + ((range.equals("100")) ? "selected" : "") + ">100</option>");
		buffer.append("<option value='200'" + ((range.equals("200")) ? "selected" : "") + ">200</option>");
		buffer.append("</select>");
		buffer.append("</td>");
		buffer.append("</tr>");
		buffer.append("</table>");
		buffer.append("</div>");

		return buffer.toString();
	}

}
